Drexel Law Review, no. Vol. 14, no 4
Thursday, December 22, 2022 13887 mots, p. 819(40)

FERTILITY CARE: ESSENTIAL OR NON-ESSENTIAL? LESSONS FROM THE COVID-19 PANDEMIC.

At the beginning of the COVID-19 pandemic, in an effort to allocate medical resources towards the anticipated influx of patients infected with the novel virus, many non-essential healthcare services were temporarily paused. The American Society of Reproductive Medicine led the move to halt infertility care in all but the most extreme cases. This cessation of infertility care, compounded by the unknown duration of this recommendation, added to the already high level of stress and anxiety that fertility patients experience and in cases of advanced maternal age or diminished ovarian reserve potentially resulted in suboptimal clinical outcomes. There was vocal disagreement amongst infertility care providers regarding the urgency and essential nature of fertility care and how this balanced with the pandemic. Ultimately there has been a full resumption of fertility care with a new emphasis on fertility preservation. It should be the goal of all professionals in the field of infertility medicine to establish fertility care as essential within the greater field of medicine to assure the protection of their patients in times of future healthcare crisis.

    TABLE OF CONTENTS
    INTRODUCTION 820
    I. PAUSE OF NON-ESSENTIAL HEALTHCARE DURING THE
     PANDEMIC 821
    II. FERTILITY CLINIC CLOSURE AND TREATMENT GUIDANCE
     DURING THE PANDEMIC 828
    III. IMPACT & PERSPECTIVES ON FERTILITY CLINIC CLOSURES 845
    IV. POLICY: FERTILITY CARE IS ESSENTIAL CARE 854
    CONCLUSION 858

INTRODUCTION

In the United States, 12.2% of women between the ages of fifteen and forty-nine have utilized infertility services to get or stay pregnant. (1) The nature of infertility treatment as either essential or non-essential came under heavy debate in the medical field at the beginning of the COVID-19 pandemic. (2) Ample data affirms that stress plays a factor in the success of fertility treatment. (3) However, many providers, responding to the guidance of their professional society, paused fertility treatment during the pandemic, adding stress and uncertainty to the fertility process. (4)

Disagreement amongst infertility care providers in the United States led to open debate regarding the essential or non-essential nature of fertility treatment. (5) The World Health Organization reiterates that infertility is a disease and that women should maintain control of their reproductive planning, even during a healthcare crisis. (6) Many employers recognize the essential nature of fertility treatment and are offering fertility benefits as a means of retaining employees during the pandemic driven worker shortage. (7)

Part I of this Article begins with an examination of non-essential healthcare that was ceased during the beginning months of the pandemic. Part II summarizes through each stage of the American Society of Reproductive Medicine's guidance on treatment during the pandemic. Part III introduces the unique impacts that the pandemic had on both infertility patients and on infertility care providers. This Article concludes in Part IV with the recommendation that fertility care be classified as essential care for all future purposes.

I. PAUSE OF NON-ESSENTIAL HEALTHCARE DURING THE PANDEMIC

In March of 2020, the reality of a global pandemic struck the United States healthcare system in multiple ways. Most notably, hospitals were tasked with preparing for the large volumes of critically ill patients whose influx was predicted to strain the medical system. (8) The increased case volume during the pandemic spawned discussions of resource allocation including hospital beds, critical care space, personal protective equipment, ventilators, and staff shortages. (9) Two of the most common responses within the healthcare system were to cancel or postpone non-urgent care and to move as much patient contact to telemedicine as possible. (10) On April 7, 2020, the Centers for Medicare and Medicaid Services (CMS) released guidance on treatment according to level of acuity. (11) For all medical treatment and services that are considered low acuity, CMS recommended either postponing or using remote interactions such as telehealth. (12) The American Hospital Association (AHA), citing the tiered framework presented by CMS, gave guidance on elective surgeries. (13) Both CMS and the AHA recommended leaving the decision in the hands of the local healthcare systems who could best factor the regional resources and COVID-19 outbreak status in their area. (14) The American College of Surgeons used the St. Louis University Elective Surgery Acuity Scale to categorize procedure acuity levels. (15) The St. Louis Scale defines low and intermediate acuity procedures as those that can be delayed safely, meaning postponement of the procedure would not present a substantial risk to the patient. (16) The American College of Surgeons advised that procedures of low and intermediate acuity should be considered for postponement in conjunction with the patient's individual medical needs and the regional status of the pandemic at the time. (17) The United States was not alone in this recommendation; there was a global consensus among healthcare providers that postponing elective and non-essential procedures was appropriate. (18)

Throughout the field of medicine there were active discussions about providing non-essential treatment in different specialties, often focused on elective surgery. (19) On April 17, 2020, the American College of Surgeons, the American Society of Anesthesiologists, the Association of periOperative Registered Nurses, and the American Hospital Association released a joint statement titled Roadmap to Resuming Elective Surgery after COVID-19 Pandemic. (20) This statement acknowledged that, under the guidance of CMS and the U.S. Surgeon General, many non-essential surgical procedures were postponed at the outset of the pandemic. (21) This statement also recognized that after the first wave of the pandemic, the American healthcare system would potentially experience an overwhelming caseload to catch-up the backlog of postponed patients. (22) The drafters intended for the joint statement to provide guidance for practitioners regarding when it will be appropriate to resume procedures and how to do so safely. (23) The joint statement relied heavily on the status of the COVID-19 pandemic in different localities, advising practitioners to wait for a fourteen-day reduction in local cases, guidance from local public health authorities, and facility staffing capabilities to determine when non-essential procedures should resume. (24) The joint statement goes on to provide guidance on how to resume surgical procedures safely, with an emphasis on COVID-19 testing, appropriate personal protective equipment (PPE) for the healthcare team, case prioritization, and scheduling. (25)

During the first twelve weeks of the pandemic, it is estimated that more than 28 million surgical procedures were cancelled worldwide. (26) To catch up on missed surgeries, surgical volume would have to be increased by twenty percent beyond standard operating levels for forty-five weeks. (27) These staggering numbers raised the question of how and when to resume non-essential services while simultaneously working to protect patients from nosocomial infection, practitioners from exposure and potential infection, and the needs of the greater healthcare system during a pandemic.

Concern for patient wellbeing in the face of a novel infectious virus must be considered when resuming operative practices for non-essential care. At this time in the pandemic, it was known that the virus transmitted via aerosol, but it was not yet proven that fomite transmission was insignificant. (28) Contracting COVID-19 in the perioperative stage was understood to have a high potential for mortality, (29) but the direct effects of COVID-19 on the surgical patient were unknown. (30) Some pathological changes in COVID-19 patients were known to lead to negative outcomes among surgical patients. (31) Negative outcomes included inflammatory responses, (32) coagulopathy, (33) and single or multiple organ failure. (34) Despite these risks, a resumption of surgical services was deemed appropriate. (35)

Though healthcare practitioners know that their chosen profession contains some level of inherent risk, appropriate precautions can minimize that risk. Healthcare practitioners with appropriate personal protective equipment (PPE) are at an 11.6% greater risk of testing positive for COVID-19 than the general population, (36) while those without access to appropriate PPE are at a 23% greater risk of testing positive for COVID-19. (37) In addition, healthcare workers have been found to be seven times more likely to have severe infection than other non-essential workers. (38) One research group postulates that there is a unique and increased risk of exposure for all members of the surgical care team, and it should therefore be assumed that the entire operating room is contaminated. (39) The researchers recommend an approach to minimize this risk which includes communicating frequently, wearing effective personal protective equipment, adopting COVID-19 specific surgical techniques, and donning and doffing using a buddy system. (40) The United States Centers for Disease Control offers guidance on the PPE that should be used, and how to use it. (41) A joint statement by British medical societies--including the Association of Anaesthetists, the Centre for Perioperative Care, the Federation of Surgical Specialty Associations, the Royal College of Anaesthetists and the Royal College of Surgeons of England--offered strategies for how to manage surgery in patients previously infected with COVID-19. (42) The World Health Organization also published guidelines on the use of PPE during the pandemic. (43)

When resuming non-essential surgery, factors to be considered must include the current COVID-19 burden on local health systems, and consequently, limited staffing resources. Nurses with experience in either anesthesia or the operating room have skills that are transferable to the critical care nursing necessary for COVID-19 patients. (44) During times of high COVID-19 infection rates, nurses assigned to surgical teams performing elective procedures, may need to be temporarily re-assigned to care for COVID-19 patients. (45) In addition to staffing considerations, healthcare systems must consider the financial ramifications of cancelling elective surgeries, which are often very lucrative and a large portion of a facility's anticipated revenue. (46) According to a 2020 study, elective surgical procedures are responsible for 78% of the total gross surgical revenue, both inpatient and outpatient. (47) Additional research demonstrates that the need to provide acute care postoperatively to patients receiving elective surgeries is consistent and predictable. (48) Thus, resuming non-essential surgeries both provides financial stability for individual healthcare entities and allows those entities to engage in contingency planning.

There are a variety of considerations in stopping and restarting non-essential surgical procedures during a pandemic. Some factors to consider include a patient's desire for the procedure and the healthcare facility's ability to provide the procedure safely, while minimizing risk of COVID-19 transmission to both the patient and the providers. Other systemic factors include drawing resources from the greater healthcare system, the current burdens placed on that healthcare system by the pandemic, and the financial burdens of restricting income to the greater healthcare system. The decision to resume non-essential surgical procedures must be made at the local institutional and provider levels, with input from public health authorities best familiar with the current state of the pandemic in that specific region.

II. FERTILITY CLINIC CLOSURE AND TREATMENT GUIDANCE DURING THE PANDEMIC

On March 11, 2020, Tedros Adhanom Ghebreyesus, the Director-General of the World Health Organization, gave a public speech in which he declared COVID-19 to be upgraded to a pandemic. (49) He announced that there were more than 118,000 cases in 114 countries and 4,291 people had already died of the coronavirus. (50) On March 13, 2020, President Donald J. Trump, in White House Proclamation 9994, declared a national emergency in accordance with the National Emergencies Act. (51) On March 17, 2020 the American Society for Reproductive Medicine (ASRM) released an advisory titled "Patient Management and Clinical Recommendations During the Coronavirus (COVID-19) Pandemic," which offered guidance on five key issues in the area of fertility treatment during the COVID-19 pandemic: (52)

(1) Suspend initiation of new treatment cycles, including ovulation induction, intrauterine inseminations (IUIs), in vitro fertilization (IVF) including retrievals and frozen embryo transfers, as well as non-urgent gamete cryopreservation.

(2) Strongly consider cancellation of all embryo transfers whether fresh or frozen.

(3) Continue to care for patients who are currently "in-cycle" or who require urgent stimulation and cryopreservation.

(4) Suspend elective surgeries and non-urgent diagnostic procedures.

(5) Minimize in-person interactions and increase utilization of telehealth. (53)

The ASRM developed a group of reproductive endocrinology and infertility specialists that comprised the Coronavirus/COVID-19 Task Force (Task Force). (54) This Task Force drafted the guidance document and its subsequent iterations, and released them with the approval of the ASRM Executive Committee. (55) The Task Force expressed the competing interests of proactively protecting healthcare systems' needs during a pandemic and the time-sensitive nature of pregnancy. (56) In addition to treatment and travel for treatment, the guidance document discusses practice management, including laboratory management and the psychological health of both clinic staff and patients. (57)

On March 19, 2020, the European Society of Human Reproduction and Embryology (ESHRE) released its first statement on fertility treatment during the pandemic, which mirrored the guidance from the ASRM. (58) ESHRE advised caution in proceeding with pregnancy based on the limited knowledge of how COVID-19 infection affects pregnancy. (59) The guidance document, with recognition of the overloaded healthcare system and an obligation to not add additional stress in that system, echoed the statements from ASRM's Task Force. (60)

At the time of this Article's publication, the Task Force has published twenty updates to its original guidance document. (61) Each update provided guidance based on the scientific knowledge and understanding of the pandemic at that given time, as well as periodic commentary on the essential nature of fertility care. (62) The remainder of this section details the individual guidance document updates and concludes with a summary in table format. (63)

The first update covered the period of time from March 30, 2020 through April 13, 2020. (64) This update affirmed the five key issues detailed in the original guidance document. (65) The Task Force relied on emerging scientific data in the literature and on governmental regulations, in addition to guidelines from other medical organizations such as the American Ambulatory Surgery Association and the American College of Surgeons. (66) The Task Force identified elective surgery as "surgery that can be delayed for a period of time without undue risk to the patient," and stated that "infertility care is not elective." (67) The Task Force also advised that as pandemic restrictions continued, practitioners must work in collaboration with their patients to determine what is urgent versus non-urgent care. (68)

The second update covered the period of time from April 13, 2020 through April 27, 2020. (69) At the time of this update, there were 1.9 million COVID-19 cases globally, more than 570,000 of which were in the United States. (70) Further, there were no available antivirals; molecular testing for the presence of the disease was expanding, but serologic testing was not yet available, and vaccines were predicted to be twelve to eighteen months away. (71) The second update again affirmed the five key issues detailed in the original guidance document and also acknowledged that an increasing number of jurisdictions were "appropriately recognizing infertility care as essential services." (72) The Task Force again acknowledged the risks of exposure for both staff and patients and urged analysis of the risks and benefits on an individual basis. (73)

The third update covered the period of time from April 24, 2020 through May 11, 2020. (74) At the time of this update there were 2.7 million COVID-19 cases globally, and more than 880,000 cases in the United States. (75) The Task Force reaffirmed their prior statement that fertility care is essential care, but expressed the need for a balance between providing fertility care and the risk of contracting COVID-19. (76) The third update was the first to give guidance on a gradual and judicious resumption of reproductive healthcare in the United States. (77) The Task Force advised that local situations be assessed for key criteria. (78) Local cases should show sustained reduction and hospitals in the area should not be resorting to crisis standards to safely treat the patient population. (79) Additionally, each individual practice must prepare to limit the risks to patients, staff, and providers. (80) The third update detailed performance standards and documented risk assessment as well as risk mitigation. (81) It relied on guidance from multiple authorities, including the Center for Disease Control (CDC), (82) the Occupational Health and Safety Administration (OSHA), (83) and the Society for Assisted Reproductive Technology (SART). (84) The update also introduced the discussion of PPE. (85)

The fourth update covered the period of time from May 11, 2020 through June 8, 2020. (86) At that time, there were nearly four million COVID-19 cases globally, over 1.3 million of which were in the United States. (87) In this update, the Task Force acknowledged the lack of vaccines and treatment for SARS-CoV-2 infection, as well as the unpredictability of the natural ebb and flow of infection rates. (88) Given the lack of knowledge about how fertility treatment and early pregnancy were affected by SARS-CoV-2 infection, the Task Force, on behalf of the ASRM, encouraged both patient and practitioner participation in research. (89) In addition, the ASRM added questions on COVID-19 to the Clinic Outcome Reporting System (CORS) that is managed by SART. (90) The fourth update also offered information on the state of testing for COVID-19, as well as an update on what was known about COVID-19 and pregnancy at that time. (91) Limited information showed that mothers infected with COVID-19 who deliver full term did well. (92) Contrarily, mothers infected with COVID-19 who were not yet full term could experience premature labor and early delivery. (93) There were no observed instances of vertical transmission from mother to fetus of COVID-19, but it was still believed to be possible. (94) There was no evidence that indicated how a SARS-CoV-2 infection during the first and second trimesters would affect the mother, fetus, or resulting child. (95) This is the first guidance document in which the Task Force addressed third-party reproduction, specifically gamete donors and gestational carriers. (96) Testing for SARS-CoV-2 was limited and gamete transmission information was ambiguous. (97) Clinics were advised to incorporate additional counseling into their standard practices for donors, carriers, and intended parents. (98) Finally, this iteration of the guidance document provided an updated PPE chart for different fertility treatments. (99)

The fifth update covered the period of time from June 8, 2020 through July 6, 2020. (100) At that time, there were 6.5 million COVID-19 cases globally, over 1.9 million of which were in the United States. (101) This was the first update to address the presence of partners during fertility treatment. (102) The Task Force recommended that only the individual receiving treatment be present in the treatment room, but it advised that other means of participation, such as telephone or video, should be considered for the patient's partner. (103) This update focused on the resumption of reproductive surgery, including oocyte harvest, in accordance with the Society for Reproductive Surgeons. (104) The Task Force reiterated its previously stated recommendations concerning local disease prevalence, patient and staff PPE, and COVID-19 testing. (105)

The sixth updated guidance document covered the period of time from July 10, 2020 through August 10, 2020. (106) At the time, the United States saw a 90% increase in cases from the prior four weeks, bringing cases in the United States to surpass three million. (107) This update again addressed third-party reproduction but focused on new studies that provided information regarding pregnancy and COVID-19. (108) A number of studies cited by the Task Force demonstrated that pregnant women were at greater risk for hospitalization, intensive care unit stay, mechanical ventilation, cesarean section, and ultimately death if determined to be SARS-CoV-2 positive in the late-second or third trimesters. (109) There was still no data on the effects of SARS-CoV-2 infection during the first and second trimesters. (110) Vertical transmission remained possible but the data was unclear and conflicting. (111)

The seventh update covered the period of time from August 10, 2020 through September 7, 2020; (112) the eighth update covered the period of time from September 8, 2020 through October 5, 2020; (113) and the ninth update covered the period of time from October 6, 2020 through November 9, 2020. (114) These three updates offered no substantial changes nor additional relevant information.

The tenth update was published on November 17, 2020. (115) At that time, there were nearly 11 million cases of COVID-19 in the United States. (116) In this update, the Task Force addressed clinic management in the face of the current surge while urging clinics to re-evaluate their risk and mitigation strategies. (117) It discussed details of the CDC recommendations for isolation and quarantine, as well as the CDC's definition of "close contact." (118) In addition, the guidance provided guidelines for previously infected healthcare workers to return to work, addressing both a symptom-based strategy and a test-based strategy. (119) It also advocated again for the use of telehealth as a means of protecting both patients and practitioners. (120) The Task Force addressed the new information regarding COVID-19 illness, fertility care, and pregnancy. (121) Though the evidence was limited, data at the time showed that the COVID-19 virus was not thought to infect gametes or embryos. (122) Most notably, two meta-analyses found that pregnant women are at significantly increased risk for admission to intensive care units and ventilatory support compared to their age-adjusted non-pregnant peers. (123) On December 11, 2020 the Food and Drug Administration (FDA) issued an Emergency Use Approval (EUA) for the Pfizer-BioNTech COVID-19 Vaccine for use in people who are sixteen years of age and older. (124)

The eleventh update to the Task Force's guidance was published on December 16, 2020. It stated that the "Task Force does not recommend withholding the vaccine from patients who are planning to conceive, who are currently pregnant, or who are lactating." (125) This statement concurred with ASRM's peer societies, including the American College of Obstetrics and Gynecology (126) and the Society for Maternal-Fetal Medicine. (127) This recommendation was based on the identification of pregnancy as a factor in severe COVID-19 disease (128) and on the fact that the vaccine does not contain live virus.

On December 17, 2020, the FDA issued an EUA for the Moderna COVID-19 vaccine for people ages eighteen and older.

The twelfth update to the Task Force's guidance was published on January 18, 2021. (129) By that time, COVID-19 cases in the United States exceeded 24 million. (130) This guidance addressed long-term effects of COVID-19, new variants of the virus, and a statement of confirmed scientific information that the Task Force termed 'truths' regarding both testing and vaccines. (131) In this document, the Task Force addressed delaying elective surgical procedures after COVID-19 infection, provided information on vaccine hesitancy, and called upon healthcare providers to be leaders by encouraging vaccination. (132)

The thirteenth update was published on February 22, 2021. (133) At this time, known COVID-19 cases in the United States exceeded 28 million and some estimates suggested actual infections were closer to 100 million people. (134) The guidance document reiterated previously stated concerns about increased risk for severe disease if COVID-19 infection occurred during pregnancy. (135) Concerns included increased risk of pre-term labor, (136) fetal death, (137) and placental injury. (138)

The fourteenth update to the Task Force's guidance was published on March 23, 2021. (139) The Task Force used this document to combat vaccine hesitancy and misinformation. (140) The fifteenth update was published on May 19, 2021, (141) and it reiterated the need for vaccination, masking, and testing. (142) The sixteenth update was published on July 23, 2021, (143) and it provided a summary of reproductive facts with regards to the vaccine. (144) The seventeenth update was published on August 20, 2021, (145) and it provided another summary on vaccination and vaccine hesitancy. (146)

The Task Force published its eighteenth update on November 12, 2021. (147) The Task Force used this update to again address vaccination and fertility care. (148) In addition to restating the need to vaccinate pregnant women due to the increased risk of severe COVID-19 during pregnancy, the Task Force overtly stated that, "[t]here are no fertility-related reasons for a vaccine exemption." (149) In a discussion of requests for medical letters of exemption, the Task Force again reiterated that, "neither infertility nor pregnancy are reasons for exemptions." (150) This update also stated that pregnant and recently pregnant patients should receive the vaccine booster shot on schedule. (151)

The Task Force published its nineteenth updated guidance document on December 17, 2021. (152) At that time, the Omicron variant was surging, and the United States had seen more than 50 million cases of COVID-19. (153) The Task Force again addressed the challenges to the American healthcare system and the issue of fertility surgery. (154) It stated that delaying surgical fertility treatment may have negative consequences for a patient's overall fertility outcomes. (155) It also advised that surgical procedures performed in response to pain or bleeding are essential treatment based on the joint statement produced by gynecologic societies. (156) The Task Force highly recommended vaccination and booster shots for all individuals who are pregnant or seeking to become pregnant, (157) in accordance with the ASRM, ACOG, SMFM, and CDC. (158) The nineteenth update concluded with a brief discussion of the current treatments for COVID-19, including monoclonal antibodies and oral antiviral therapy. (159)

On April 22, 2022 the Task Force published its twentieth and final update to the guidance document and titled it, "Summary Statement Two Years Out." (160) This update provided no new information but rather reviewed and summarized core recommendations presented over the last two years including epidemiology, vaccination and telemedicine use. (161) This is followed by a summary of how to continue fertility practice operations in the context of endemic COVID-19 including surveillance, screening, action and staying informed. (162) The conclusion notes that this will be the last scheduled update but that the Task Force will re-convene if necessary. (163)

III. IMPACT & PERSPECTIVES ON FERTILITY CLINIC CLOSURES

Fertility clinic closures at the beginning of the pandemic, while recommended by the American Society of Reproductive Medicine (ASRM), had a ripple effect in the field of reproductive medicine. Though the pause on fertility care may have prevented healthcare-acquired infections in patients and clinic staff, it created significant psychological strain (165) and potentially led to negative impacts on treatment outcomes, particularly for women of advanced maternal age. (166) Early data from the SART's Clinic Outcome Reporting System indicated that approximately the same number of in vitro fertilization (IVF) cycles were run in 2019 and 2020, leading to the conclusion that cycles may have been delayed but not cancelled. (167) Given the steep increase in women freezing their eggs for fertility preservation during the pandemic, (168) it is also possible that the similar quantity of IVF cycles could simply indicate a shift in fertility clinic clientele. An Italian study with 1,482 participants found that just over one third (37.3%) who were planning to have a child changed their minds in the pandemic in favor of not procreating, while only 11.5% of those who previously did not intend to have a child changed their minds in favor of procreation. (169) It is therefore possible that those whose cycles were cancelled early in the pandemic never completed their fertility treatment, and the patient volume was replaced with fertility preservation patients.

At its most fundamental level, fertility treatment comes with an inherent uncertainty that often leads to anxiety and depression. (170) The uncertainty introduced by the pandemic combined with the pause of fertility care added additional layers of uncertainty to an already stressful process. This additional stress was demonstrated in a study that found that 50% of survey respondents had fertility treatments cancelled or postponed, and nearly three quarters of these respondents expressed some level of increased distress. (171) Their distress was evidenced by severe sleep disturbances, feeling anxious, mood disturbances, and having depressive thoughts. (172) A similar study found that a number of factors played into the severity of a patient's emotional distress. (173) More distress was exhibited by older patients and single patients. (174) Additionally, patients who expressed that suspending treatments was unjustified exhibited greater distress and felt a sense of helplessness. (175) The results of yet another study concurred that a sense of loss of control was derived from both the treatment delays of unknown length and the questions these delays raise about the individual's future procreation. (176) The study reported that almost all respondents experienced negative emotions that outweighed positive emotions, demonstrating increased stress, frustration, and worry. (177) In discussions of postponing fertility treatment, some point out that the element of choice was removed from the patient's control. (178) In other words, clinics ceased to offer fertility care, which prevented each individual patient from factoring for themselves where the crux of the balance is between delaying their fertility care and risking nosocomial infection.

The additional stress that the pandemic added to fertility treatment was managed in a variety of ways by different patients. Some couples sought professional counseling through virtual platforms. (179) Others resorted to social media to share their distress, seeking updates on clinic openings and closings, forming support webinars, and engaging with fellow fertility patients through Instagram Live. (180) A study from the Mayo Clinic found that fertility patients with interrupted care identified an increased need for psychological support. (181) Experts in the field confirmed the Mayo Clinic's findings, indicating that patients with delayed treatment experienced both increased anxiety and increased emotional distress as compared to fertility patients who did not experience delays in treatment. (182) They further found that the psychological effects were more significant in patients with longer histories of infertility, and they ultimately concluded that the psychological consequences of postponed fertility care due to the pandemic must not be undervalued. (183) Another study identified the five most frequently used coping skills by fertility patients whose treatment was on hold during the pandemic. (184) These five skills were, "establishing a daily routine, going outside regularly, exercising, maintaining social connection via phone, social media or Zoom and continuing to work. (185)

For many, the distress of pausing fertility treatments was compounded by the inequitable distribution of clinic closures and durations of closure. The guidelines published by ASRM were merely guidelines. (186) As a professional advisory body, the ASRM has no ability to enforce its guidance in the professional sphere beyond collegial peer-pressure. (187) This inability to enforce the ASRM guidance resulted in significant variability of infertility treatment between clinics and regions. For example, at one extreme, every fertility clinic in the city of Cincinnati ceased providing care entirely for up to twelve weeks at the beginning of the pandemic. (188) At the other extreme were organizations like Reproductive Medical Associates, which operates nineteen fertility clinics in the United States, that declared its facilities would stay open and operate at full capacity. (189) Many found a middle ground of practice. For example, organizations like the Colorado Center for Reproductive Medicine, with ten fertility centers in the United States and two in Canada, opted to continue egg retrievals and gamete and embryo cryopreservation, but paused embryo and sperm transfers. (190) In other words, they continued with fertility preservation but did not perform procedures intended to initiate pregnancy. Some clinics were creative in their methods of providing care. The Center for Human Reproduction categorized certain cases as urgent, specifically women over forty years of age, women with diminished ovarian reserve, and women with impending cancer treatments, and proceeded with their care. (191) Additionally, the Center for Human Reproduction initiated an "Online Second Opinion Program" designed to provide review of individual patient cases in preparation for restarting fertility when the pandemic allowed. (192) This varied approach to clinic management during the beginning of the pandemic left many patients wondering why some could access continued fertility care while others could not. (193)

Practitioners have also exhibited varied responses to the initial guidance released by ASRM's Task Force. Most notable was the formation of the Fertility Providers Alliance (the "Alliance") to provide an alternative association for fertility specialists. (194) The Alliance, "was established by providers of reproductive medicine on behalf of the tens of thousands of patients [they] collectively serve." (195) Its "goals are to expand access to care, deliver high quality fertility services, and continuously advocate for [its] patients." (196) The Alliance is comprised of over 425 fertility care providers, representing nearly fifty medical practices, including the large fertility clinics such as Boston IVF and Reproductive Medicine Associates. (197) The members section of the Alliance's website has recruiting statements for fertility provider membership that solicit members of, "the reproductive medicine field to join [its] alliance and help [it] continue to give a stronger voice to [its] patients." (198) The Alliance also formed a task force to address the issue of fertility center operations during the beginning of the pandemic. (199) Members of this task force include prominent reproductive endocrinologists, such as a co-founder of Boston IVF, the director of NYU Langone Fertility Center, the founder and medical director of Colorado Center for Reproductive Medicine, the co-founder of Shady Grove Fertility, and the chief executive officer of Reproductive Medical Associates. (200)

On April 2, 2020 the Alliance's Task Force released the first of two public statements regarding the provision of fertility care during the pandemic. (201) The Task Force stated that it shared with the ASRM their concerns about the recommendations made in the initial guidance document, (202) while simultaneously applauding the ASRM for recognizing infertility as a disease. (203) On April 24, 2020, the Alliance released a second public statement, which included the "FPA Toolkit." (204) The FPA Toolkit is intended to be used alongside resources provided by other national health authorities, and includes general COVID-19 consent forms, general disclaimers, and strategies for practicing ART during COVID-19. (205) These documents, along with the press release, show a clear intent on behalf of the Alliance to guide fertility clinics in providing the full range of reproductive care during the pandemic. (206) No further advisories or guidance documents have been released by the Alliance and its website has not been updated since. (207)

The Alliance wrote an undated public letter to Ricardo Azziz, the then Chief Executive Officer of ASRM and the ASRM Task Force, which was not published on the Alliance website. (208) A copy of this letter was published by Dr. Norbert Gleicher, the Medical Director of the Center for Human Reproduction, in his online blog titled, The Voice. (209) In its letter, the Alliance requested to discuss the ASRM Task Force's Guidance Document. (210) They provided an agenda compromised of the following three issues, "first, the actual public health burden created by the continuation of fertility care: second, the classification of infertility treatment as 'non-urgent' or elective; and third, the harmful consequences of an indeterminate delay in access to care." (211) The letter went on to discuss details of these three topics, explaining that most fertility care is provided in clinics and independent surgical centers, and therefore, their continued operation would not impact hospital capacity during the pandemic. (212) Dr. Gleicher goes on to interpret the meaning and intent of the Alliance's letter, denoting a financially driven intent from private sector fertility care. (213) He noted that the Alliance was formed, and its task force was created, specifically to counter the ASRM's Task Force and refers to that as, "a quite frightening scam the investor-driven IVF-world is trying to pull off." (214) Gleicher also offered his own interpretation of the ASRM's Task Force Guidance. (215) He differentiates his clinic as an IVF center that treats older patients (citing that the average fertility patient age is thirty-six, although the Center for Human Reproduction identifies the average fertility patient age as forty-three) and patients with premature ovarian aging. (216) He interprets his patients' treatment as urgent because these conditions make a three month delay in treatment due to the ASRM guidance critical for his patients. (217) He goes on to state that other clinics' primary populations are younger and therefore would not meet such a qualification. (218) In a second blog post, Dr. Gleicher acknowledged the tone change between the first and second press releases from the Alliance. (219) He credited this change to the shift from the identified Alliance representative being the CEO of a large IVF company to being two physicians representing IVF clinics. (220) The sentiment of concern about the financial motivations of investment-driven decision making is neither new nor confined to the bounds of the pandemic. (221)

Fertility care providers are divided regarding whether treatments should have been paused at the beginning of the pandemic. (222) The sheer volume of reproductive endocrinologists who endorsed either the ASRM or the Alliance shows the rift in the medical community regarding the urgency and essential nature of different fertility treatments. (223) Although there is some consensus on fertility preservation for cancer patients, (224) beyond that, there is no agreement. (225) For example, the results of a 2020 study demonstrated that pausing fertility care for one month in the United States would result in 369 fewer live births, (226) while another study concluded that pausing fertility treatment for 180 days did not alter the live-birth rate. (227) From contradicting studies to conflicting professional opinions based on training and experience, it is easy to see how the fertility community fractured into two separate professional societies as the pandemic exposed the unique challenges of providing healthcare during a global public health emergency.

IV. POLICY: FERTILITY CARE IS ESSENTIAL CARE

The COVID-19 pandemic provided many lasting lessons in the field of healthcare, ranging from resource allocation to public health structure and prioritization. The field of infertility medicine is no exception to these lessons learned, the most valuable of which is the need to clarify infertility as a disease and therefore infertility care as essential healthcare. The need to consider infertility care as essential is emphasized by the implications of the American Society of Reproductive Medicine's guidance documents. (228) The newly formed Fertility Providers Alliance stresses the same need to classify infertility care as essential. (229) As additional waves of the COVID-19 pandemic or other public health crises befall society, it is the obligation of healthcare systems to recognize the essential role that time plays in the treatment of a fertility patient. Postponing treatment has the potential to undermine the efficacy of that treatment and to result in suboptimal outcomes. These postponements have negative ramifications on the mental health of the patients seeking treatment. (230) Furthermore, postponing treatment raised serious concerns of treatment dropout without return, (231) though there is evidence of increased fertility preservation patients. (232)

Within the field of medicine there are a plethora of definitions for essential care. As a result, what qualifies as essential care during a time of crisis varies by perspective. Many of the arguments in favor of postponing non-essential care were founded in the need to protect the greater healthcare system and the ability to respond to the influx of pandemic patients. (233) Pausing non-essential care that draws from resources which may be re-allocated to treat pandemic patients is logical to preserve those resources. (234) For example, significant medical procedures such as joint replacements, spinal fusions, and bariatric procedures were temporarily paused in most cases because the resources necessary to perform these invasive procedures overlap with the resources necessary to treat the increasing number of COVID-19 patients. (235) These resources included critical care nurse staff, ventilators, and hospital bed space. (236) Infertility care, even at its most invasive stages such as egg harvest or hysteroscopy, does not utilize the same hospital resources. (237) In many cases, private fertility clinics either have their own operating suites or contract with outpatient surgical centers. Even in most academic infertility practices, the operating and recovery rooms are separate from critical care rooms used for high acuity patients. Therefore, it is not necessary to pause fertility treatment to preserve resources in the greater healthcare system.

The practice of infertility, particularly egg harvest procedures, is best analogized to ophthalmic care, which continued in many cases throughout the pandemic. (238) Though the American Academy of Ophthalmology recommended pausing all care that was not urgent or emergent, it left the definition of urgent and emergent to the individual ophthalmologist. (239) Both ophthalmic and infertility care are timely and life altering for the patient receiving the treatment.

In addition, both surgical interventions are minimally invasive, performed under a range of light or twilight sedation, requiring minimal supervision during recovery. Most significantly, with the exception of some academic practices, both cataract surgery and egg harvest are performed at facilities outside a hospital that would not otherwise be used for critical patients. Given that cataract surgery was considered essential and continued throughout the pandemic for many, infertility interventions such as egg harvest should have been treated the same way.

The arguments to pause infertility treatment as non-essential had two origins. The first argument was to protect and preserve limited healthcare resources during a time of crisis with the looming threat of systemic overload. Given the independent nature of infertility care and the lack of overlap with critical care, this argument is not valid. The second argument was concern for the safety of both the patients and practitioners, (240) but it stands to reason that if patients receiving care considered to be essential can be treated in a safe environment, all patients can receive care under an umbrella of safety. (241) Furthermore, given that the next crisis that limits the provision of infertility care may not be a communicable disease but rather a natural disaster or military conflict, it is important to establish that infertility care is essential and should continue.

The lines between essential and non-essential care are poorly defined and blurred by the bias of the party giving the definition. Organizations internal to the field have an inherent bias, hence the fracture between the ASRM and the Alliance. There should be a national governing body, such as the American Medical Association, that determines which areas of healthcare are essential and which are not. This would allow for universal application of rules in a time of crisis, removing some of the ambiguity that caused additional moral distress from the kaleidoscope of treatment practices during the COVID-19 pandemic.

It should be the goal of all professionals in the field of fertility medicine and their professional organizations to establish infertility care as essential medicine within the greater field of healthcare to protect future patients seeking critical and time-sensitive fertility treatment.

CONCLUSION

In the early months of the COVID-19 pandemic, in an effort to protect the larger healthcare system, services deemed to be non-essential were halted with indeterminate duration. The field of infertility medicine was one such area of healthcare, resulting in the temporary pause of fertility treatments for many patients. The inability for many to access fertility treatment added significant psychological strain to an already high-stress process and for women of advanced maternal age or diminished ovarian reserve, potentially led to a suboptimal outcome. Infertility care providers publicly expressed disagreement regarding the status of fertility treatment as essential and thus compounded the distress patients experienced by implementing inequitable and disproportionate pauses in practice. Moving forward all professionals who practice infertility medicine should uniformly present fertility care as essential medicine in the context of the field of healthcare.

Rebecca S. Feinberg (*)

(*) Rebecca Feinberg is a Teaching Associate Professor in the College of Science and Health and a Lecturer in Law in the College of Law at DePaul University. Thank you to my colleagues Michael Sinha of Saint Louis University School of Law and Danielle Pacia of the Hastings Center for reading and providing feedback on drafts of this article. A huge thank you to the Drexel Law Review team, specifically Kelcie Ouillette, for the invaluable feedback she provided on multiple drafts of this article.

(1.) See Infertility, CDC, https://www.cdc.gov/nchs/fastats/infertility.htm (last visited June 4, 2022).

(2.) See Shailin A. Thomas & Arthur L. Caplan, Are Infertility Treatments 'Essential'? How To Ethically Determine What Kind of Care Must Go On Amid Covid-19, STAT (Apr. 30, 2020), https://www.statnews.com/2020/04/30/infertility-treatments-essential-or-not-during-covid-19-pandemic/; see also Natalie Lampert, Fertility Clinics Stay Open Despite Unclear Guidelines, N.Y. TIMES, https://www.nytimes.com/2020/05/01/parenting/fertility-clinics-coronavirus.html (May 4, 2020).

(3.) Shilpa Prasad, Meenakshi Tiwari, Ashutosh N. Pandey, Tulsidas G. Shrivastav & Shail K. Chaube, Impact of Stress on Oocyte Quality and Reproductive Outcome, 23 J. BIOMEDICAL SCIS. 36 (2016); Kristin L. Rooney & Alice D. Domar, The Relationship Between Stress and Infertility, 20 DIALOGUES CLINICAL NEUROSCIENCE 41, 42 (2018).

(4.) See Gabriela Weigel, Alina Salganicoff & Usha Ranji, Potential Impacts of Delaying "Non-Essential" Reproductive Health Care, KAISER FAM. FOUND. (June 24, 2020), https://www.kff.org/womens-health-policy/issue-brief/potential-impacts-of-delaying-non-essential-reproductive-health-care/.

(5.) See Maria do Carmo Borges de Souza, Hitomi Nakagawa, Paulo Franco Taitson, Emerson Barchi Cordts & Roberto Azevedo Antunes, Management of ART and COVID-19: Infertility in Times of Pandemic. What Now?, 24 JBRA ASSISTED REPROD. 231, 231 (2020).

(6.) WHO, WHO CONSOLIDATED GUIDELINE ON SELF-CARE INTERVENTIONS FOR HEALTH: SEXUAL AND REPRODUCTIVE HEALTH AND RIGHTS 140, 5-6 (2019), https://apps.who.int/iris/bitstream/handle/10665/325480/9789241550550-eng.pdf.

(7.) See, e.g., Megan Leonhardt, Companies Are Scrambling to Get Ahead of the Great Resignation by Beefing Up Fertility Benefits. Here's What They're Offering., FORTUNE (Jan. 31, 2022, 3:53 PM), https://fortune.com/2022/01/31/companies-fertility-benefits-great-resignation/.

(8.) See OFF. OF INSPECTOR GEN., DEP'T OF HEALTH AND HUM. SERVS., HOSPITAL EXPERIENCES RESPONDING TO THE COVID-19 PANDEMIC: RESULTS OF A NATIONAL PULSE SURVEY MARCH 23-27, 2020, at 5 (2020), https://oig.hhs.gov/oei/reports/oei-06-20-00300.pdf [hereinafter HOSPITAL EXPERIENCES].

(9.) See Ezekiel J. Emanuel, Govind Persad, Ross Upshur, Beatriz Thome, Michael Parker, Aaron Glickman, Cathy Zhang, Connor Boyle, Maxwell Smith & James P. Phillips, Fair Allocation of Scarce Medical Resources in the Time of Covid-19, 382 NEW ENG. J. MED. 2049, 2050 (2020); HOSPITAL EXPERIENCES, supra note 8, at 1-5.

(10.) See Lisa M. Koonin, Brooke Hoots, Clarisse A. Tsang, Zanie Leroy, Kevin Farris, B. Tilman Jolly, Peter Antall, Bridget McCabe, Cynthia B.R. Zelis, Ian Tong & Aaron M. Harris, Trends in the Use of Telehealth During the Emergence of the COVID-19 Pandemic--United States, January--March 2020, CTRS. FOR DISEASE CONTROL AND PREVENTION (Oct. 30, 2020), https://www.cdc.gov/mmwr/volumes/69/wr/mm6943a3.htm; Hallie Golden, US Hospitals Postpone Non-Emergency Procedures Amid Coronavirus Pandemic, GUARDIAN (Mar. 25, 2020, 3:27 PM), https://www.theguardian.com/world/2020/mar/25/us-hospitals-coronavirus-pandemic-postpone-elective-surgery-procedures.

(11.) See Non-Emergent, Elective Medical Services, and Treatment Recommendations, CTRS. FOR MEDICARE & MEDICAID SERVS. (Apr. 7, 2020), https://www.cms.gov/files/document/cms-non-emergent-elective-medical-recommendations.pdf.

(12.) Id.

(13.) New Information on Elective Surgery, PPE Conservation and Additional COVID-19 Issues, AM. HOSPITAL ASS'N (Mar. 19, 2020), https://www.aha.org/system/files/media/file/2020/03/new-information-on-elective-surgery-ppe-conservation-additional-covid-19-issues-3-18-2020.pdf.

(14.) Id.

(15.) COVID-19: Guidance for Triage of Non-Emergent Surgical Procedures, AM. COLL. OF SURGEONS (Mar. 17, 2020), https://www.facs.org/covid-19/clinical-guidance/triage.

(16.) Id.

(17.) Id.

(18.) See COVIDSurg Collaborative, Global Guidance for Surgical Care During the COVID-19 Pandemic, 107 BRIT. J. SURGERY 1097, 1098 (2020); Gareth Iacobucci, Covid-19: All Non-Urgent Elective Surgery Is Suspended for At Least Three Months in England, BMJ (Mar. 18, 2020), https://www.bmj.com/content/bmj/368/bmj.m1106.full.pdf.

(19.) See Ken Wu, Craig R. Smith, Bradley T. Lembcke & Tanira B.D. Ferreira, Elective Surgery During the Covid-19 Pandemic, 383 NEW ENG. J. MED. 1787, 1787-90 (2020); Caroline V. Gona, Letter to the Editor, Cancellation of Elective Surgery During the COVID-19 Pandemic, 25 E. & CENT. AFR. J. SURGERY 33, 33 (2020); J. Wayne Meredith, Kevin P. High & Julie Ann Freischlag, Preserving Elective Surgeries in the COVID-19 Pandemic and the Future, 324 J. AM. MED. ASS'N 1725, 1725-26 (2020). For an example of such discussions in other specialties, see Thomas & Caplan, supra note 2.

(20.) See Joint Statement: Roadmap for Resuming Elective Surgery After COVID-19 Pandemic, AM. SOC'Y OF ANESTHESIOLOGISTS (Apr. 17, 2020), https://www.asahq.org/about-asa/newsroom/news-releases/2020/04/joint-statement-on-elective-surgery-after-covid-19-pandemic.

(21.) Id.

(22.) Id.

(23.) Id.

(24.) Id.

(25.) Id.

(26.) Helene Charbonneau, Segolene Mrozek, Benjamin Pradere, Jean-Nicolas Cornu & Vincent Misrai, How to Resume Elective Surgery in Light of COVID-19 Post-Pandemic Propofol Shortage: The Common Concern of Anaesthesists and Surgeons, 39 ANAESTHESIA CRITICAL CARE & PAIN MED. 593, 593 (2020).

(27.) COVIDSurg Collaborative, Elective Surgery Cancellations Due to the COVID-19 Pandemic: Global Predictive Modelling to Inform Surgical Recovery Plans, 107 BRIT. J. SURGERY 1440, 1440 (2020).

(28.) See Knvul Sheikh, Derek Watkins, Jin Wu & Mika Grondahl, How Bad Will the Coronavirus Outbreak Get? Here Are 6 Key Factors, N.Y. TIMES, https://www.nytimes.com/interactive/2020/world/asia/china-coronavirus-contain.html (Feb. 28, 2020) (providing key facts surrounding Covid-19, as it was understood in late February 2020, such as the virus's ability to spread through the air, but making no mention of fomite transmission).

(29.) Ali Aminian, Saeed Safari, Abdolali Razeghian-Jahromi, Mohammad Ghorbani & Conor P. Delaney, COVID-19 Outbreak and Surgical Practice: Unexpected Fatality in Perioperative Period, 272 ANNALS OF SURGERY e27, e27 (2020); see Shaoqing Lei, Fang Jiang, Wating Su, Chang Chen, Jingli Chen, Wei Mei, Li-Ying Zhan, Yifan Jia, Liangqing Zhang, Danyong Liu, Zhong-Yuan Xia & Zhengyuan Xia, Clinical Characteristics and Outcomes of Patients Undergoing Surgeries During the Incubation Period of COVID-19 Infection, 21 ECLINICALMEDICINE 1, 7 (2020).

(30.) See Lei et al., supra note 29, at 2.

(31.) See Chuan Qin, Luoqi Zhou, Ziwei Hu, Shuoqi Zhang, Sheng Yang, Yu Tao, Cuihong Xie, Ke Ma, Ke Shang, Wei Wang & Dai-Shi Tian, Dysregulation of Immune Response in Patients with Coronavirus 2019 (COVID-19) in Wuhan, China, 71 CLINICAL INFECTIOUS DISEASES 762, 767 (2020).

(32.) See id.

(33.) See Huan Han, Lan Yang, Rui Liu, Fang Liu, Kai-lang Wu, Jie Li, Xing-hui Liu & Cheng-liang Zhu, Prominent Changes in Blood Coagulation of Patients with SARS-CoV-2 Infection, 58 CLINICAL CHEMISTRY & LAB'Y MED. 1116, 1119 (2020).

(34.) See Tianbing Wang, Zhe Du, Fengxue Zhu, Zhaolong Cao, Youzhong An, Yan Gao & Baoguo Jiang, Comorbidities and Multi-Organ Injuries in the Treatment of COVID-19, 395 LANCET e52, e52 (2020); K. Soreide, J. Hallet, J. B. Matthews, A. A. Schnitzbauer, P. D. Line, P. B. S. Lai, J. Otero, D. Callegaro, S. G. Warner, N. N. Baxter, C. S. C. Teh, J. Ng-Kamstra, J. G. Meara, L. Hagander & L. Lorenzon, Immediate and Long-Term Impact of the COVID-19 Pandemic on Delivery of Surgical Services, 107 BRIT. J. SURGERY 1250, 1255 (2020).

(35.) Soreide et al., supra note 34, at 1255.

(36.) COPE Consortium, Risk of COVID-19 Among Frontline Healthcare Workers and the General Community: A Prospective Cohort Study, NAT'L INSTS. OF HEALTH (May 25, 2020), https://www-ncbi-nlm-nih-gov.univ-eiffel.idm.oclc.org/pmc/articles/PMC7273299/.

(37.) Id.

(38.) Healthcare Workers 7 Times as Likely to Have Severe COVID-19 as Other Workers, BMJ (Aug. 12, 2020), https://www.bmj.com/company/newsroom/healthcare-workers-7-times-as-likely-to-have-severe-covid-19-as-other-workers/.

(39.) Gabriel A. Brat, Sean Hersey, Karan Chhabra, Alok Gupta & John Scott, Protecting Surgical Teams During the COVID-19 Outbreak: A Narrative Review and Clinical Considerations, ANNALS OF SURGERY, Apr. 17, 2020, at 3.

(40.) Id.

(41.) See Personal Protective Equipment: Questions and Answers, CTRS. FOR DISEASE CONTROL & PREVENTION, https://www.cdc.gov/coronavirus/2019-ncov/hcp/respirator-use-faq.html (Apr. 9, 2022).

(42.) K. El-Boghdadly, T.M. Cook, T. Goodacre, J. Kua, L. Blake, S. Denmark, S. McNally, N. Mercer, S.R. Moonesinghe & D.J. Summerton, SARS-CoV-2 Infection, COVID-19 and Timing of Elective Surgery, 76 ANAESTHESIA 940 (2021).

(43.) World Health Org. [WHO], Rational Use of Personal Protective Equipment for Coronavirus Disease 2019 (COVID-19), WHO Doc. WHO/2019-nCov/IPC PPE_use/2020.1 (Feb. 27, 2020), https://apps.who.int/iris/bitstream/handle/10665/331215/WHO-2019-nCov-IPCPPE_use-2020.1-eng.pdf.

(44.) Nick Evans, Elective Care: Catching Up and Staying COVID-Free, 35 NURSING STANDARD 67, 67 (2020).

(45.) See id.

(46.) See id. at 67-68.

(47.) Joseph E. Tonna, Heidi A. Hanson, Jessica N. Cohan, Marta L. McCrum, Joshua J. Horns, Benjamin S. Brooke, Rupam Das, Brenna C. Kelly, Alexander John Campbell & James Hotaling, Balancing Revenue Generation with Capacity Generation: Case Distribution, Financial Impact and Hospital Capacity Changes from Cancelling or Resuming Elective Surgeries in the US During COVID-19, 20 BMC HEALTH SERVS. RSCH., 1119, 1121-22 (2020).

(48.) Vijay Krishnamoorthy, Tetsu Ohnuma, Raquel Bartz, Matthew Fuller, Nita Khandelwal, Krista Haines, Charles Scales & Karthik Raghunathan, Acute Care Resource Use After Elective Surgery in the United States: Implications During the COVID-19 Pandemic, 30 AM. J. CRITICAL CARE 320, 320-23 (2021).

(49.) Tedros Adhanom Ghebreyesus, Dir. Gen., World Health Org., Opening Remarks at the Media Briefing on COVID-19 (Mar. 11, 2020), https://www.who.int/director-general/speeches/detail/who-director-general-s-opening-remarks-at-the-media-briefing-on-covid-19--11-march-2020.

(50.) Id.

(51.) Proclamation No. 9994, 85 Fed. Reg. 15337 (Mar. 18, 2020); see 50 U.S.C. [section] 1621.

(52.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforce.pdf.

(53.) Id. It should be noted that this document and each subsequent update raised the issue of mental health for both providers and patients. See id. at 5-7; COVID-19 Updates and Resources, AM. SOC'Y FOR REPROD. MED., https://www.asrm.org/news-and-publications/covid-19/ (last visited June 4, 2022).

(54.) AM. SOC'Y FOR REPROD. MED., supra note 52, at 2; COVID, Reproductive Health, and Public Policy: Lessons Learned after Two Years of the Ongoing Pandemic, AM. SOC'Y FOR REPROD. MED., (Mar. 2, 2022), https://www.asrm.org/news-and-publications/news-and-research/announcements/covid-reproductive-health-and-public-policy-lessons-learned-after-two-years-of-the-ongoing-pandemic-from-the-asrm-covid-19-task-force/ (describing the makeup of the Task Force).

(55.) AM. SOC'Y FOR REPROD. MED., supra note 52, at 2.

(56.) Id. at 1-2.

(57.) Id. at 5-7.

(58.) See Coronavirus Covid-19: ESHRE Statement on Pregnancy and Conception, EUR. SOC'Y OF HUM. REPROD. & EMBRYOLOGY (Mar. 19, 2020), https://www.eshre.eu/Europe/Position-statements/COVID19.

(59.) Id.; see also Huan Liang & Ganesh Acharya, Novel Corona Virus Disease (COVID-19) in Pregnancy: What Clinical Recommendations to Follow?, 99 ACTA OBSTETRICIA ET GYNECOLOGICA SCANDINAVICA 4, 439-42 (2020); David A. Schwartz & Ashley L. Graham, Potential Maternal and Infant Outcomes from (Wuhan) Coronavirus 2019-nCoV Infecting Pregnant Women: Lessons from SARS, MERS, and Other Human Coronavirus Infection, 12 VIRUSES 194 (2020).

(60.) Id.; AM. SOC'Y FOR REPROD. MED., supra note 52, at 3-7.

(61.) COVID-19 Updates and Resources, supra note 53.

(62.) See infra pp. 10-20; see also COVID-19 Updates and Resources, supra note 53.

(63.) See infra pp. 843-845.

(64.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE #1 (MARCH 30, 2020 THROUGH APRIL 13, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate1.pdf.

(65.) Id.

(66.) Id. at 2.

(67.) Id.

(68.) Id.

(69.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE #2 (APRIL 13, 2020 THROUGH APRIL 27, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate2.pdf.

(70.) Id.

(71.) Id.

(72.) Id. at 1-2.

(73.) See id. at 2.

(74.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE # 3 (APRIL 24, 2020 THROUGH MAY 11, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate3.pdf [hereinafter ASRM, UPDATE #3].

(75.) Id.

(76.) Id. at 2.

(77.) See id.

(78.) See id.

(79.) Id. at 3. The Task Force suggested that a reduction in cases for a period of at least fourteen days would be considered "sustained." Id.

(80.) See id.

(81.) See id. at 3-6.

(82.) Id. at 4, 8 tbl.1.

(83.) Id.; OCCUPATIONAL SAFETY & HEALTH ADMIN., U.S. DEP'T OF LAB., GUIDANCE ON PREPARING WORKPLACES FOR COVID-19 1 (2020), https://www.osha.gov/sites/default/files/publications/OSHA3990.pdf.

(84.) ASRM, UPDATE #3, supra note 74, at 9 tbl.1; SOC'Y FOR ASSISTED REPROD. TECH., SART COVID-19 TOOLKIT 1 (2020), https://www.sart.org/globalassets/__sart/covid-19/tips-for-resuming-care/sart-covid-19-toolkit.pdf.

(85.) See ASRM, UPDATE #3, supra note 74, at 6.

(86.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE #4 (MAY 11, 2020 THROUGH JUNE 8, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate4.pdf [hereinafter ASRM, UPDATE #4].

(87.) Id. at 2.

(88.) See id.

(89.) Id.; see, e.g., Heather Huddleston, Assessing the Safety of Pregnancy in the Co[r]onavirus (COVID-19) Pand[e]mic, UCSF CLINICAL TRIALS, https://clinicaltrials.ucsf.edu/trial/NCT04388605 (last visited Apr. 4, 2022).

(90.) ASRM, UPDATE #4, supra note 86, at 2.

(91.) See id. at 3-6.

(92.) See Wissam Shalish, Satyanarayana Lakshminrusimha, Paolo Manzoni, Martin Keszler & Guilherme M. Sant'Anna, COVID-19 and Neonatal Respiratory Care: Current Evidence and Practical Approach, 37 AM. J. PERINATOLOGY 780, 780 (2020).

(93.) See Yangli Liu, Haihong Chen, Kejing Tang & Yubiao Guo, Clinical Manifestations and Outcomes of SARS-Cov-2 Infection During Pregnancy, 82 J. INFECT. e9, e9-e10 (2021).

(94.) See Huijun Chen, Juanjuan Guo, Chen Wang, Fan Luo, Xuechen Yu, Wei Zhang, Jiafu Li, Dongchi Zhao, Dan Xu, Qing Gong, Jing Liao, Huixia Yang, Wei Hou & Yuanzhen Zhang, Clinical Characteristics and Intrauterine Vertical Transmission Potential of COVID-19 Infection in Nine Pregnant Women: A Retrospective Review of Medical Records, 395 LANCET 809, 810, 814 (2020).

(95.) See ASRM, UPDATE #4, supra note 86, at 3-5.

(96.) Id. at 6-7.

(97.) Id. at 5.

(98.) Id. at 7.

(99.) Id. at 8.

(100.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #5 (JUNE 8, 2020 THROUGH JULY 6, 2020), 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate5.pdf [hereinafter ASRM, UPDATE #5].

(101.) Id. at 2.

(102.) See id. at 4-5.

(103.) Id.

(104.) Id. at 3.

(105.) Id.

(106.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #6 (JULY 10, 2020 THROUGH AUGUST 10, 2020), 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate6.pdf

[hereinafter ASRM, UPDATE #6].

(107.) Id. at 2.

(108.) Id. at 2-5.

(109.) Id.; Matthew J. Blitz, Burton Rochelson, Howard Minkoff, Natalie Meirowitz, Lakha Prasannan, Viktoriya London, Timothy J. Rafael, Shruti Chakravarthy, Luis A. Bracero, Shane W. Wasden, Sarah L. Pachtman Shetty, Orlando Santandreu, Frank A. Chervenak, Benjamin M. Schwartz & Michael Nimaroff, Maternal Mortality Among Women with Coronavirus Disease 2019 Admitted to the Intensive Care Unit, 223 AM. J. OBSTETRIC GYNECOLOGY 595 (2020); Sascha Ellington, Penelope Strid, Van T. Tong, Kate Woodworth, Romeo R. Galang, Laura D. Zambrano, John Nahabedian, Kayla Anderson & Suzanne M. Gilboa, Characteristics of Women of Reproductive Age with Laboratory-Confirmed SARS-CoV-2 Infection by Pregnancy Status--United States, January 22-June 7, 2020, 69 MORBIDITY MORTALITY WKLY. REP. 769-775 (2020); Rasha Khoury, Peter S. Bernstein, Chelsea Debolt, Joanne Stone, Desmond M. Sutton, Lynn L. Simpson, Meghana A. Limaye, Ashley S. Roman, Melissa Fazzari, Christina A. Penfield, Lauren Ferrara, Calvin Lambert, Lisa Nathan, Rodney Wright, Angela Bianco, Brian Wagner, Dena Goffman, Cynthia Gyamfi-Bannerman, William E. Schweizer, Karina Avila, Bijan Khaksari, Meghan Proehl, Fabiano Heitor, Johanna Monro, David L. Keefe, Mary E. D'Alton, Michael Brodman, Sharmila K. Makhija & Siobhan M. Dolan, Characteristics and Outcomes of 241 Births to Women with Severe Acute Respiratory Syndrome Coronavirus 2 (SARS-CoV-2) Infection at Five New York City Medical Centers, 136 OBSTETRICS & GYNECOLOGY 273-282 (2020); Marian Knight, Kathryn Bunch, Nicola Vousden, Edward Morris, Nigel Simpson, Chris Gale, Patrick O'Brien, Maria Quigley, Peter Brocklehurst & Jennifer J Kurinczuk, Characteristics and Outcomes of Pregnant Women Admitted to Hospital with Confirmed SARS-CoV-2 Infection in UK: National Population-Based Cohort Study, 369 BMJ 2107 (2020); Reem Matar, Layan Alrahmani, Nasser Monzer, Labib G Debiane, Elie Berbari, Jawad Fares, Fidelma Fitzpatrick & Mohammad H. Murad, Clinical Presentation and Outcomes of Pregnant Women with Coronavirus Disease 2019: A Systematic Review and Meta-Analysis, 72 CLINICAL INFECTIOUS DISEASES 521-33 (2021).

(110.) See Blitz et al., supra note 109 at 596; Miranda J. Delahoy, Michael Whitaker, Alissa O'Halloran, Shua J. Chai, Pam Daily Kirley, Nisha Alden, Breanna Kawasaki, James Meek, Kimberly Yousey-Hindes, Evan J. Anderson, Kyle P. Openo, Maya L. Monroe, Patricia A. Ryan, Kimberly Fox, Sue Kim, Ruth Lynfield, Samantha Siebman, Sarah Shrum Davis, Daniel M. Sosin, Grant Barney, Alison Muse, Nancy M. Bennett, Christina B. Felsen, Laurie M. Billing, Jessica Shiltz, Melissa Sutton, Nicole West, William Schaffner, H. Keipp Talbot, Andrea George, Melanie Spencer, Sascha Ellington, Romeo R. Galang, Suzanne M. Gilboa, Van T. Tong, Alexandra Piasecki, Lynnette Brammer, Alicia M. Fry, Aron J. Hall, Jonathan M. Wortham, Lindsay Kim & Shikha Garg, Characteristics and Maternal and Birth Outcomes of Hospitalized Pregnant Women with Laboratory-Confirmed COVID-19--COVID-NET, 13 States, March 1--August 22, 2020, 69 MORBIDITY MORTALITY WKLY. REP. 1347-48 (2020).

(111.) See Gabriela N. Algarroba, Patricia Rekawek, Sevan A. Vahanian, Poonam Khullar, Thomas Palaia, Morgan R. Peltier, Martin R. Chavez & Anthony M. Vintzileos, Visualization of Severe Acute Respiratory Syndrome Coronavirus 2 Invading the Human Placenta Using Electron Microscopy, 223 AM. J. OBSTETRICS & GYNECOLOGY 2, 275-278 (2020); David Baud, Gilbert Greub, Guillaume Favre, Carole Gengler, Katia Jaton, Estelle Dubruc & Leo Pomar, Second-Trimester Miscarriage in a Pregnant Woman with SARS-CoV-2 Infection, 323 JAMA 21, 2198-2200 (2020); Lan Dong, Jinhua Tian, Songming He, Chuchao Zhu, Jian Wang, Chen Liu & Jing Yang, Possible Vertical Transmission of SARS-CoV-2 From an Infected Mother to Her Newborn, 323 JAMA 21, 1846-48 (2020); Koen Grimminck, Lindy Anne Maria Santegoets, Frederike Charlotte Siemens, Pieter Leendert Alex Fraaij, Irwin Karl Marcel Reiss & Sam Schoenmakers, No Evidence of Vertical Transmission of SARS-CoV-2 After Induction of Labour in an Immune-Suppressed SARS-CoV-2-Positive Patient, 13 BMS CASE REP. 6 (2020); Wissman Shalish, Satyanarayana Lakshminrusimha, Paolo Manzoni, Martin Keszler & Guilherme M. Sant'Anna, COVID-19 and Neonatal Respiratory Care: Current Evidence and Practical Approach, 37 AM J. PERINATOLOGY 08, 780-91 (2020).

(112.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #7, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate7.pdf [hereinafter ASRM, UPDATE #7].

(113.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #8, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate8.pdf [hereinafter ASRM, UPDATE #8].

(114.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #9, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate9.pdf.

(115.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #10, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate10.pdf.

(116.) Id.

(117.) Id. at 2.

(118.) Id. at 4.

(119.) Id.

(120.) Id.

(121.) Id.

(122.) See M. Barragan, N. Martin-Palomino, A. Rodriguez & R. Vassena, Undetectable Viral RNA in Oocytes from SARS-CoV-2 Positive Women, 36 HUM. REPROD. 390 (2020); Yajun Ruan, Bintao Hu, Zhuo Liu, Kang Liu, Hongyang Jiang, Hao Li, Rui Li, Yang Luan, Xiaming Liu, Gan Yu, Shengfei Xu, Xiaoyi Yuan, Shaogang Wang, Weimin Yang, Zhangqun Ye, Jihong Liu & Tao Wang, No Detection of SARS-CoV-2 from Urine, Expressed Prostatic Secretions and Semen in 74 Recovered COVID-19 Male Patients: A perspective and Urogenital Evaluation, 9 ANDROLOGY 99, 100 (2020).

(123.) John Allotey, Elena Stallings, Mercedes Bonet, Magnus Yap, Shaunak Chatterjee, Tania Kew, Luke Debenham, Anna Clave Llavall, Anushka Dixit, Dengyi Zhou, Rishab Balaji, Siang Ing Lee, Xiu Qiu, Mingyang Yuan, Dyuti Coomar, Jameela Sheikh, Heidi Lawson, Kehkashan Ansari, Madelon van Wely, Elizabeth van Leeuwen, Elena Kostova, Heinke Kunst, Asma Khalil, Simon Tiberi, Vanessa Brizuela, Nathalie Broutet, Edna Kara, Caron Rahn Kim, Anna Thorson, Ramon Escuriet, Olufemi T Oladapo, Lynne Mofenson, Javier Zamora & Shakila Thangaratinam, PregCOV-19 Living Systematic Review Consortium. Clinical Manifestations, Risk Factors, and Maternal and Perinatal Outcomes of Coronavirus Disease 2019 in Pregnancy: Living Systematic Review and Meta-Analysis, BMJ 1, 7 (2020); Laura Zambrano, Laura D. Zambrano, Sascha Ellington, Penelope Strid, Romeo R. Galang, Titilope Oduyebo, Van T. Tong, Kate R. Woodworth, John F. Nahabedian III, Eduardo Azziz-Baumgartner, Suzanne M. Gilboa & Dana Meaney-Delman, Update: Characteristics of Symptomatic Women of Reproductive Age with Laboratory-Confirmed SARS-CoV-2 Infection by Pregnancy Status--United States, January 22--October 3, 2020, 69 MORBIDITY & MORTALITY WKLY. REP. 1641, 1646 (2020).

(124.) AM. SOC'Y OF REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE NO. 11 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate11.pdf [hereinafter ASRM, UPDATE #11]; see also FDA News Release, FDA Takes Additional Action in Fight Against COVID-19 By Issuing Emergency Use Authorization for Second COVID-19 Vaccine (Dec. 18, 2020), https://www.fda.gov/news-events/press-announcements/fda-takes-additional-action-fight-against-covid-19-issuing-emergency-use-authorization-second-covid.

(125.) See ASRM, UPDATE #11, supra note 124.

(126.) ACOG, VACCINATING PREGNANT AND LACTATING PATIENTS AGAINST COVID-19 (2020), http://www.aofog.net/pdf/Vaccinating%20Pregnant%20and%20Lactating%20Patients%20Against%20COVID-19%20_%20ACOG.pdf.

(127.) SMFM, SOCIETY FOR MATERNAL-FETAL MEDICINE (SMFM) STATEMENT: SARS-COV-2 VACCINATION IN PREGNANCY (2020), https://s3.amazonaws.com/cdn.smfm.org/media/2591/SMFM_Vaccine_Statement_12-1-20_(final).pdf.

(128.) Julius Collin, Emma Bystrom, AnnaSara Carnahan & Malin Ahrne, Public Health Agency of Sweden's Brief Report: Pregnant and Postpartum Women with Severe Acute Respiratory Syndrome Coronavirus 2 Infection in Intensive Care in Sweden, 99 ACTA OBSTET. GYNECOL. SCAND. 819, 819(2020); Miranda J. Delahoy et al., Characteristics and Maternal and Birth Outcomes of Hospitalized Pregnancy Women with Laboratory-Confirmed COVID-19--COVID-NET, 13 States, March 1--August 22, 2020, 69 MORBIDITY MORTAL WKLY. REP. 1347, 1347, 1351-53 (2020); Lakshmi Panagiotakopoulos, Tanya R. Myers, Julianne Gee, Heather S. Lipkind, Elyse O. Kharbanda, Denison S. Ryan, Joshua T.B. Williams, Allison L. Naleway, Nicola P. Klein, Simon J. Hambidge, Steven J. Jacobsen, Jason M. Glanz, Lisa A. Jackson, Tom T. Shimabukuro, Eric S. Weintraub, SARS-Cov-2 Infection Among Hospitalized Pregnant Women: Reasons for Admission and Pregnancy Characteristics--Eight U.S. Health Care Centers, March 1--May 30, 2020, 69 MORBIDITY MORTAL WKLY. REP. 1355, 1355, 1356 (2020).

(129.) ASRM, TESTING AND VACCINE TRUTHS (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate12.pdf.

(130.) Id.

(131.) Id.

(132.) Id.

(133.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #13 (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate13.pdf.

(134.) Id.

(135.) Id.

(136.) See John Allotey, Elena Stallings, Mercedes Bonet, Magnus Yap, Shaunak Chatterjee, Tania Kew, Luke Debenham, Anna Clave Llavall, Anushka Dixit, Dengyi Zhou, Rishab Balaji, Siang Ing Lee, Xiu Qiu, Mingyang Yuan, Dyuti Coomar, Jameela Sheikh, Heidi Lawson, Kehkashan Ansari, Madelon van Wely, Elizabeth van Leeuwen, Elena Kostova, Heinke Kunst, Asma Khalil, Simon Tiberi, Vanessa Brizuela, Nathalie Broutet, Edna Kara, Caron Rahn Kim, Anna Thorson, Ramon Escuriet, Olufemi T Oladapo, Lynne Mofenson, Javier Zamora & Shakila Thangaratinam, Clinical Manifestations, Risk Factors, and Maternal and Perinatal Outcomes of Coronavirus Disease 2019 in Pregnancy: Living Systematic Review and Meta-Analysis, BMJ (Sept. 1, 2020), https://www.bmj.com/content/bmj/370/bmj.m3320.full.pdf.

(137.) See Elizabeth V. Kingston, High Rates of Stillbirth and Preterm Delivery in Women with Covid-19 and the Efficacy of ECMO in Pregnancy, BMJ (July 27, 2020), https://www.bmj.com/content/bmj/370/bmj.m2921.full.pdf.

(138.) See J. Justin Mulvey, Cynthia M. Magro, Lucy X. Ma, Gerard J. Nuovo & Rebecca N. Baergen, Analysis of Complement Deposition and Viral RNA in Placentas of COVID-19 Patients, 46 ANNALS DIAGNOSTIC PATHOLOGY (2020), https://www-sciencedirect-com.univ-eiffel.idm.oclc.org/science/article/pii/S109291342030071X?via%3Dihub; see also Alice Lu-Culligan, Arun R. Chavan, Pavithra Vijayakumar, Lina Irshaid, Edward M. Courchaine, Kristin M. Milano, Zhonghua Tang, Scott D. Pope, Eric Song, Chantal B.F. Vogels, William J. Lu-Culligan, Katherine H. Campbell, Arnau Casanovas-Massana, Santos Bermejo, Jessica M. Toothaker, Hannah J. Lee, Feimei Liu, Wade Schulz, John Fournier, M. Catherine Muenker, Adam J. Moore, Yale IMPACT Team, Liza Konnikova, Karla M. Neugebauer, Aaron Ring, Nathan D. Grubaugh, Albert I. Ko, Raffaella Morotti, Seth Guller, Harvey J. Kliman, Akiko Iwasaki & Shelli F. Farhadian, SARS-Cov-2 Infection in Pregnancy is Associated with Robust Inflammatory Response at the Maternal-Fetal Interface, MEDRXIV (2021), https://www-ncbi-nlm-nih-gov.univ-eiffel.idm.oclc.org/pmc/articles/PMC7852242/.

(139.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #14 (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate14.pdf.

(140.) Id.

(141.) Am. Soc'y for Reprod. Med. Press Release, ASMR Covid-19 Task Force Update #15 (May 19, 2021), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/asrm-covid-19-task-force-update-15.

(142.) Id.

(143.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #16, (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate16.pdf.

(144.) Id.

(145.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #17 (2021), http://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate17.pdf.

(146.) Id.

(147.) Am. Soc'y for Reprod. Med. Press Release, UPDATE No. 18 - COVID-19: Vaccination, Booster Shots and Reproductive Health Care (Nov. 12, 2021), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/update-no-18-covid-19-vaccination-booster-shots-and-reproductive-health-care.

(148.) Id.

(149.) Id.

(150.) Id.

(151.) Id.

(152.) Am. Soc'y for Reprod. Med. Press Release, UPDATE No. 19--Awareness of Complexity in Uncertain Times (Dec. 17, 2021), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/update-no.-19--awareness-of-complexity-in-uncertain-times-covid-19.

(153.) Id.

(154.) Id.

(155.) Id.

(156.) Id.

(157.) Id.

(158.) Id.

(159.) Id.

(160.) Am. Soc'y for Reprod. Med. Press Release, ASRM COVID-19 Task Force Issues Update No. 20 (Apr. 20, 2022), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/asrm-covd-19-task-force-issues-update-no.-20/

(161.) Id.

(162.) Id.

(163.) Id.

(164.) See discussion supra pp. 831-843.

(165.) Olivia Solon, 'Adding Insult to Injury': Couples Struggle with IVF Cancellations Amid Coronavirus Pandemic, NBC NEWS (Apr. 1, 2021, 6:00 AM), https://www.nbcnews.com/health/health-news/adding-insult-injury-couples-struggle-ivf-cancellations-amid-coronavirus-pandemic-n1173256 (recounting interviews with ten women and some of their partners about the impact of coronavirus-related disruptions in IVF treatment cycles have had on their mental states).

(166.) Covid Delays in IVF Treatment Has Biggest Impact on Women Over 40, UNIV. OF ABERDEEN (Jan. 20, 2021), https://www.abdn.ac.uk/news/14623/.

(167.) Austin D. Schirmer, Jennifer F. Kawwass & Eli Y. Adashi, Fertility Care Amidst the COVID19 Pandemic: The American Experience, J. OVARIAN RSCH. 1, 2-3 (2021).

(168.) Eliana Dockterman, Data Show More Women Are Freezing Their Eggs During the Pandemic, Defying Doctors' Expectations, TIME (Jan. 13, 2021, 1:52PM), https://time.com/5927516/egg-freezing-covid-19-pandemic/; Anne E. Martini, Samad Jahandideh, Ali Williams, Kate Decine, Erica A. Widra, Micah J. Hill, Alan H. DeCherney & Jeanne E. O'Brien, Trends In Elective Egg Freezing Before and After the COVID-19 Pandemic, 116 FERTILITY & STERILITY e220, 264 (2021); Mary Plfum, Egg Freezing Has Boomed During The Pandemic, As Women Opt To Wait Out Family Life, NBC NEWS (Apr. 24, 2021, 6:00AM), https://www.nbcnews.com/business/business-news/egg-freezing-has-boomed-during-pandemic-women-opt-wait-out-n1264211.

(169.) Elisabetta Micelli, Gianmartin Cito, Andrea Cocci, Gaia Polloni, Giorgio I. Russo, Andrea Minervini, Marco Carini, Alessandro Natali & Maria E. Coccia, Desire for Parenthood at the Time of COVID-19 Pandemic: An Insight into the Italian Situation, 41 J. PSYCHOSOMATIC OBSTETRICS GYNAECOLOGY 183, 185-86 (2020).

(170.) C.M. Verhaak, J.M.J Smeenk, A. van Minnen, J.A.M. Kremer & F.W. Kraaimaat, A Longitudinal, Prospective Study on Emotional Adjustment Before, During and After Consecutive Fertility Treatment Cycles, 20 HUM. REPROD. 2253, 2253 (2005).

(171.) Harpreet Kaur, Gautham T. Pranesh, & Kamini A. Rao, Emotional Impact of Delay in Fertility Treatment Due To COVID-19 Pandemic, 13 J. HUM. REPROD. SCI. 317, 319 (2020).

(172.) Id. at 320.

(173.) Reut Ben-Kimhy, Michal Youngster, Tamar R. Medina-Artom, Sarit Avraham, Itai Gat, Lilach M. Haham, Ariel Hourvitz & Alon Kedem, Fertility Patients Under COVID-19: Attitudes, Perceptions and Psychological Reactions, 35 HUM. REPROD. 2774, 2774-83 (2020).

(174.) Id. at 2777.

(175.) Id.

(176.) J. Boivin, C. Harrison, R. Mathur, G. Burns, A. Pericleous-Smith & S. Gameiro, Patient Experiences of Fertility Clinic Closure During The COVID-19 Pandemic: Appraisals, Coping and Emotions, 35 HUM. REPROD. 2556, 2556 (2020); see also David B. Seifer, William D. Petok, Alisha Agrawal, Tanya L. Glenn, Arielle H. Bayer, Barry R. Witt, Blair D. Burgin & Harry J. Lieman, Psychological Experience and Coping Strategies of Patients in the Northeast US Delaying Care for Infertility During the COVID-19 Pandemic, 19 REPROD. BIOLOGY & ENDOCRINOLOGY 1, 2 (2021).

(177.) Boivin et al., supra note 176, at 2556-57, 2561.

(178.) Nadia Muhaidat, Mohammad A. Alshrouf, Abdulrahman M. Karam & Mohammed Elfalah, Infertility Management Disruption During the COVID-19 Outbreak in a Middle-Income Country: Patients' Choices, Attitudes, and Concerns, 15 PATIENT PREFERENCE & ADHERENCE 2279, 2284 (Oct. 5, 2020), https://www-ncbi-nlm-nih-gov.univ-eiffel.idm.oclc.org/pmc/articles/PMC8502047/pdf/ppa-15-2279.pdf.

(179.) Fatemeh Hamidi, Farzaneh Babapour & Zeinab Hamzehgardeshi, Infertility Distress Management in Couples Treated with Assisted Reproductive Techniques (ART) in COVID-19 Pandemic, 21 J. REPROD. INFERTILITY 312, 312-13 (2020).

(180.) See Julie Morgan, Andreia Trigo & Kate Davies, Assessing the Change in Infertility Patient's Social Media Use During COVID-19 Related to Clinic Closures, 114 FERTILITY & STERILITY, P-987, P-987 (2020).

(181.) Karen Dsouza, Minerva Orellana, Alessandra Ainsworth, Kirsten Riggan, Chandra Shenoy & Megan Allyse, Patient Perceptions of COVID-19 Impact on their Fertility Care, 5 J. CLINICAL & TRANSLATIONAL SCI. 85, 85 (2021).

(182.) See Veronica Esposito, Erika Rania, Daniela Lico, Sara Pedri, Alessia Fiorenza, Maria Francesca Strati, Alessandro Conforti, Vincenzo Marrone, Andrea Carosso, Alberto Revelli, Fulvia Zullo, Costantino Di Carlo & Roberta Venturella, Influence of COVID-19 Pandemic on the Psychological Status of Infertile Couples, 253 EUR. J. OF OBSTETRICS & GYNECOLOGY & REPROD. BIOLOGY 148, 149-150 (2020).

(183.) Id. at 152.

(184.) Seifer, supra note 176.

(185.) Id.

(186.) See generally discussion supra Part II (noting documents released by ASRM are merely for guidance).

(187.) See id.

(188.) Alissa Greenberg, The Pandemic Disrupted Tens of Thousands of IVF Cycles, PBS: NOVA (May 14, 2021), https://www.pbs.org/wgbh/nova/article/ivf-covid-pandemic-infertility/.

(189.) Natalie Lampert, Fertility Clinics Stay Open Despite Unclear Guidelines, NY TIMES, https://www.nytimes.com/2020/05/01/parenting/fertility-clinics-coronavirus.html (last updated May 4, 2020).

(190.) CCRM Fertility to Remain Open for Select Fertility Treatments as a Commitment to Patient Health and Safety, CCRM FERTILITY (Mar. 16, 2020), https://www.ccrmivf.com/news-events/remains-open/; Hannam Fertility Centre is a CCRM Network Clinic, CCRM FERTILITY, https://www.ccrmivf.com/toronto/ (last visited April 5, 2020).

(191.) Norbert Gleicher, IVF During COVID-19: CHR's Always-Up-To-Date Guide, CTR. FOR HUM REPROD., https://www.centerforhumanreprod.com/blog/ivf-during-covid-19-chrs-always-up-to-date-guide (last updated Nov. 13, 2020).

(192.) Id.

(193.) See generally Fertility Providers Alliance Issues Comprehensive Tool Kit Designed to Help Fertility Practices Navigate Care in a COVID-19 World, FERTILITY PROVIDERS ALL. (Apr 24, 2020), https://www.fertilityprovidersalliance.com/blogs/fpa_releases_covid_19_toolkit#article (discussing that FPA's Toolkit was "[d]esigned to be used in conjunction with other resources provided by ASRM") [hereinafter Fertility Providers Alliance Tool Kit].

(194.) See generally Our Story Starts with You, FERTILITY PROVIDERS ALL., https://www.fertilityprovidersalliance.com/index.html (last visited Apr. 7, 2022).

(195.) Id.

(196.) Id.

(197.) Id.

(198.) Id.

(199.) Anna Louie Sussman, Is Getting Pregnant "Medically Necessary" Right Now?, MIT TECH. REV. (May 7, 2020), https://www.technologyreview.com/2020/05/07/1000473/ivf-covid-fertility-prelude-inception-asrm/.

(200.) Our Story Starts with You, supra note 194.

(201.) See FPA Applauds ASRM for Revised Recommendations on Fertility Care During Pandemic, FERTILITY PROVIDERS ALL. (Apr. 2, 2020), https://www.fertilityprovidersalliance.com/blogs/fpa_applauds_asrm.

(202.) See discussion of ASRM's initial guidance supra pp. 828-830.

(203.) See Norbert Gleicher, Fertility Providers' Alliance (FPA) Reframes ASRM's Reaffirmation of COVID-19 Guidelines, CTR. FOR HUM. REPROD. (Apr. 6, 2020), https://www.centerforhumanreprod.com/blog/fertility-providers-alliance-fpa-reframes-asrms-reaffirmation-of-covid-19-guidelines.

(204.) Fertility Providers Alliance Tool Kit, supra note 193.

(205.) Id.

(206.) See id.

(207.) See The Latest News and Events from the Fertility Providers Alliance, FERTILITY PROVIDERS ALL., https://www.fertilityprovidersalliance.com/news.html (last visited Mar. 17, 2022).

(208.) See id.

(209.) Norbert Gleicher, What the "Controversy" Over ASRM COVID-19 Task Force's Recommendation is All About, CTR. FOR HUM. REPROD. (Apr. 2, 2020), https://www.centerforhumanreprod.com/blog/what-the-controversy-over-asrm-covid-19-task-forces-recommendation-is-all-about [hereinafter What the "Controversy" Over ASRM COVID-19 Task Force's Recommendations is All About].

(210.) Id.

(211.) Id.

(212.) See id.

(213.) Id.

(214.) Id.

(215.) See id.

(216.) Id.

(217.) Id.

(218.) Id.

(219.) See What the "Controversy" Over ASRM COVID-19 Task Force's Recommendations is All About, supra note 209.

(220.) Id.

(221.) See, e.g., Alexander Borsa, Joseph Bruch & Sarah S. Richardson, When Private Equity Firms Invest in Women's Health Clinics, Who Benefits?, STAT (Sept. 14, 2020), https://www.statnews.com/2020/09/14/private-equity-firms-invest-womens-health-clinics-who-benefits/; Patrick Krause, Industry Voices--Fertility Clinics Offer Big Potential for Investors and Physician Practices, FIERCE HEALTHCARE (Sept. 26, 2019, 12:00 PM), https://www.fiercehealthcare.com/hospitals-health-systems/industry-voices-fertility-clinics-offer-big-potential-for-investors-and; Alexander Borsa & Joseph Dov Bruch, Prevalence and Performance of Private Equity-Affiliated Fertility Practices in the United States, 117 FERTILITY & STERILITY 124, 124-25, 128 (2022).

(222.) See What the "Controversy" Over ASRM COVID-19 Task Force's Recommendations is All About, supra note 209.

(223.) Id.

(224.) See Miriam Dellino, Carla Minoia, Angelo Virgilio Paradisio, Raffaella De Palo & Erica Silvestris, Fertility Preservation in Cancer Patients During the Coronvirus (COVID-19) Pandemic, 10 FRONTIERS IN ONCOLOGY 1, 3 (2020); Bhawna Sirohi, Tanya Buckshee Rohatgi & Matteo Lambertini, Oncofertility and COVID-19--Cancer Does Not Wait, 14 ECANCER 1, 2 (2020).

(225.) See Andrew Smith, Piotr Gromski, Karema Al Rashid, Kate Tilling, Deborah Lawlor & Scott Nelson, Population Implications of Cessation of IVF During the COVID-19 Pandemic, 41 REPROD. BIOMED ONLINE 428, 430 (2020).

(226.) Id. at 429.

(227.) Phillip A. Romanski, Pietro Bortoletto, Zev Rosenwaks & Glenn L. Schattman, Delay in IVF Treatment Up to 180 Days Does Not Affect Pregnancy Outcomes in Women with Diminished Ovarian Reserve, 35 HUM. REPROD. 1630, 1634 (2020).

(228.) See AM. SOC'Y FOR REPROD. MED., supra note 52, at 2, 6.

(229.) See Our Story Starts with You, supra note 194.

(230.) Jenna M. Turocy, Alex Robles, Daniel Hercz, Mary D'Alton, Eric J. Forman & Zev Williams, The Emotional Impact of the ASRM Guidelines on Fertility Patients During the COVID-19 Pandemic, 114 FERTILITY AND STERILITY e63, e63 (2020).

(231.) Laura C. Gemmell, Zev Williams & Eric J. Forman, Considerations on the Restriction of Assisted Reproductive Technology (ART) Due to COVID-19, SEMINARS IN PERINATOLOGY, Nov. 2020, at 1, 1.

(232.) Beth Zhou, Ammar Joudeh, Milli J. Desai, Brian Kwan, Vinit Nalawade, Brian W. Whitcomb & H. Irene Su, Trends in Infertility Care Among Commercially Insured US Women During the COVID-19 Pandemic, JAMA NETWORK OPEN, Oct. 6, 2021, at 1, 3.

(233.) See, e.g. COVID-19: Recommendations for Management of Elective Surgical Procedures, AM. COLL. OF SURGEONS (Mar. 13, 2020), https://www.facs.org/for-medical-professionals/covid-19/clinical-guidance/elective-surgery/.

(234.) See CMS, NON-EMERGENT, ELECTIVE MEDICAL SERVICES, AND TREATMENT RECOMMENDATIONS 1 (2020), https://www.cms.gov/files/document/cms-non-emergent-elective-medical-recommendations.pdf.

(235.) Krishnamoorthy, et al., supra note 48, at 321-22.

(236.) Id. at 322.

(237.) See, e.g., In Vitro Fertilization (IVF), MAYO CLINIC (Sept. 10, 2021), https://www.mayoclinic.org/tests-procedures/in-vitro-fertilization/about/pac-20384716 (discussing the process of IVF at an outpatient clinic, with no mention of the utilization of hospital resources); Hysteroscopy, MOUNT SINAI, https://www.mountsinai.org/health-library/surgery/hysteroscopy (Dec. 3, 2020) (explaining that a hysteroscopy may be done in a hospital, outpatient surgery center, or provider's office, but patients typically go home the same day).

(238.) See Matthew R. Starr, Rachel Israilevich, Michael Zhitnitsky, Qianqian E. Cheng, Rebecca R. Soares, Luv G. Patel, Michael J. Ammar, M. Ali Khan, Yoshihiro Yonekawa, Allen C. Ho, Michael N. Cohen, Jayanth Sridhar & Ajay E. Kuriyan, Practice Patterns and Responsiveness to Simulated Common Ocular Complaints Among US Ophthalmology Centers During the COVID-19 Pandemic, 138 JAMA OPHTHALMOLOGY 981, 985-86 (2020).

(239.) Recommendations for Urgent and Nonurgent Patient Care, AM. ACAD. OF OPHTHALMOLOGY (Mar. 18, 2020), https://www.aao.org/headline/new-recommendations-urgent-nonurgent-patient-care.

(240.) See Boivin, et al., supra note 176, at 2557.

(241.) See Thomas & Caplan, supra note 2.

    Table 1
    ASRM TASK FORCE GUIDANCE (164)
    Update Time Period
    Number Covered or
     Date Published
     1 March 30 -
     April 13, 2020
     2 April 13 - April
     27, 2020
     3 April 24 - May
     11, 2020
     4 May 11 - June 8,
     2020
     5 June 8 - July 6,
     2020
     6 July 10 -
     August 10, 2020
     7 August 10 -
     September 7,
     2020
     8 September 8 -
     October 5, 2020
     9 October 6 -
     November 9,
     2020
    10 November 17,
     2020
    11 December 16,
     2020
    12 January 18, 2021
    13 February 22,
     2021
    14 March 23, 2021
    15 May 19, 2021
    16 July 23, 2021
    17 August 20, 2021
    18 November 12,
     2021
    19 December 17,
     2021
    20 April 22, 2022
    Update Summary of Update
    Number
     1 Affirmed the five key issues and clinical
     recommendations associated with fertility
     during the COVID-19 pandemic; stated
     that infertility care is not elective.
     2 Acknowledged that an increasing number
     of jurisdictions appropriately recognized
     infertility care as an essential service.
     3 Expressed the need for balance between
     providing fertility care and risk of
     contracting COVID-19; first update to
     provide guidance on gradual resumption
     of reproductive services.
     4 Encouraged patient and practitioner
     participation in research due to lack of
     knowledge about effects of COVID-19 on
     fertility treatment and early pregnancy;
     provided update on current knowledge of
     effects on pregnancy.
     5 Focused on resumption of reproductive
     surgery; advised that partners should not
     be present in treatment room.
     6 Discussed emerging data on negative
     effects of more severe COVID-19 cases
     during pregnancy.
     7 No substantial changes.
     8 No substantial changes.
     9 No substantial changes.
    10 Addressed clinic management and urged
     clinics to re-evaluate risk and mitigation
     strategies; advocated for use of telehealth;
     addressed new data regarding COVID-19
     and fertility care and pregnancy.
    11 Stated that it does not recommend
     withholding COVID-19 vaccines from
     pregnant, soon-to-be pregnant, or
     lactating patients.
    12 Addressed long-term effects of COVID-
     19, variants, and confirmed information
     regarding testing and vaccines.
    13 Reiterated concerns about increased risk
     for severe disease if infected during
     pregnancy.
    14 Provided information to counter vaccine
     hesitancy and misinformation.
    15 Reiterated need for vaccination, masking,
     and testing.
    16 Summarized reproductive facts regarding
     vaccination.
    17 Provided additional information on
     vaccination and vaccine hesitancy.
    18 Explicitly stated that there are no fertility
     or pregnancy related reasons for vaccine
     exemption.
    19 Discussed negative effects on
     reproductive outcome if surgical
     intervention is delayed.
    20 Summarized recommendations issued
     during the prior two years; offered
     guidance on the provision of fertility care
     in the context of the continuing
     pandemic.

Note(s):

At the beginning of the COVID-19 pandemic, in an effort to allocate medical resources towards the anticipated influx of patients infected with the novel virus, many non-essential healthcare services were temporarily paused. The American Society of Reproductive Medicine led the move to halt infertility care in all but the most extreme cases. This cessation of infertility care, compounded by the unknown duration of this recommendation, added to the already high level of stress and anxiety that fertility patients experience and in cases of advanced maternal age or diminished ovarian reserve potentially resulted in suboptimal clinical outcomes. There was vocal disagreement amongst infertility care providers regarding the urgency and essential nature of fertility care and how this balanced with the pandemic. Ultimately there has been a full resumption of fertility care with a new emphasis on fertility preservation. It should be the goal of all professionals in the field of infertility medicine to establish fertility care as essential within the greater field of medicine to assure the protection of their patients in times of future healthcare crisis.

Loughborough Echo (UK)
News, Wednesday, December 28, 2022 4632 mots, p. 16

VILLAGES.

East Leake Mike Elliott 0115 937 6506 [email protected]

PAVILION PROVING POPULAR. As the new PS1m sports pavilion at East Leake comes into use, early bookings show it is going to be well used, not just for sports events but general use as well.

The pavilion -- provided in a scheme established by the parish council -- on the edge of the Costock Road sports ground, has a main central hall that looks set to be a winner for village social and other events.

Funding for the new facility has been not only from local sources but also from, the Premier football league, the Football; Association and Government through the Football Foundation. The parish council have assisted cash wise as have Rushcliffe Borough Council through its Community Infrastructure Levy.

As well as the public space in the new building, there are of course facilities for kts main use, sport, including showers, toilets, modern changing rooms, a kitchen and bar area and two club rooms that have disabled access. Two football pitches are provided on the playing fields as well as a rugby pitch and a cricket pitch.

GROWTH BOARDS. East Leake remains a part of the Growth Boards established in Rushcliffe alongside West Bridgford, Bingham and Radcliffe-on-Trent.

At its last meeting the East Leake group looked at a number of points of local interest including an update from Severn Trent Water on infrastructure schemes, East Leake Traders Association and the High Street consultant updated on their joint

initiatives, an update from the Parish Council on welcome back funding spend and an update on Health Centre plans.

The Growth Board groups are made up of public sector partners, local representatives of the community and business sectors who are working together to agree, plan and implement a long term vision for their area.

The facility ensures the areas concerned have the support and infrastructure in place to meet the needs of the existing and future residents as these settlements grow in the coming years.

Anyone can find out more about the items and local issues the Boards have addressed so far and hear of updates following their regular meetings at https:// www.rushcliffe.gov.uk/ business/growthboards/ The Borough is growing significantly over the next decade with 13,150 new homes planned by 2028, and the Growth Boards are an integral part of ensuring they proactively plan to create communities that will be desirable to live, work and play in.

Coun. Andy Edyvean, Cabinet Portfolio Holder for Economic Growth and

Business says : "This area of our website is now a central point for all enquiries for the latest in each of our Growth Board areas.

"It is important that we are keeping people informed of the work of the growth boards and how their plans are progressing and developing.

"Updates will be posted on the webpage following each quarterly meeting so we would encourage residents to look out for further updates."

Activity undertaken across all of the Growth Board areas so far includes a retail health check of each area to

understand the challenges and opportunities within Rushcliffe's high streets and accompanying workshops for local businesses.

Rushcliffe is part of the WDYT --What do you think? -- campaign which measures the Digital Influence of 1,300 UK high streets and help them improve them for their local communities.

Coun. Edyvean says the WDYT social media campaign last year was also used to encourage more small independent retailers to adopt the use of social media and drive up footfall on the high street.

Shop front improvement grants have been introduced to support local retailers and the Great British High Street social media campaign championed Rushcliffe's local high streets, which has evolved into a High Street Heroes campaign to further highlight their initiatives.

Examples of some of the activity that has taken place in East Leake includes work to support and enhance the village centre including a meeting with NCC Highways to explore options for the T junction, sewerage and drainage, and completion of capacity assessment by Severn Trent Water to assess the impact of the housing growth in East Leake.

The Group have already held an action planning workshop which has resulted in the production of an action plan to help guide the groups work..

FESTIVE SERVICES. After staging a successful and well supported Nativity service with local brownies taking part, East Leake Methodist Church held a Christmas Eve Midnight service and then on Christmas Day while not having their own service some members sent to other Methodist churches in the

area including Shepshed where they had been given a special invitation.

TOOLS WITH A MISSION. Residents in East Leake are being reminded that the parish church of St Mary's are still looking for donations of any unwanted but usable tools, to make available in Africa where they could transform someone's life.

The church, as a base in the village for the Tools with a Mission charity. say they can accept agricultural and gardening, builders, and carpenters tools, as well as electricians tools along with mechanics, plumbers and power tools. In addition they would also be happy to

accept sewing and knitting machines, haberdashery and full working computers.

A collection point is arranged on the first Saturday of each month at The Rectory at 3 Bateman Road between 9am and 11am when donations can be handed in.

The charity is based in Ipswich with centres around the country. They send around 18 containers a year to Africa and say the scheme is a wonderful chanced to get those unused tools out of the shed put them to good use.

Mr Roy Bates was behind the start up of the scheme at East Leake which has proved to be very successful and which has already seen at least 12 sewing machines handed in for sending off.

WI. Keen to increase its membership, East Leake Womens Institute invite newcomers -- and all others as well of course - to the village to visit the Institutes page on the village website for a copy of the full programme of the very varied list of meetings and other activities.

The branch assure new members they will be given a

warm welcome as they join into find out details of what happens at the monthly gathering in the village hall.

Membership secretary is Carolyn Barnett and she will be happy to give out information to anyone seeking it.

FOLK CLUB. Formed over 10 years ago, East Leake Folk Club continue tio meet regularly on the first and third Tuesdays of each month in the room, at the rear of the N ags Head public house on Main Street.

The sessions start at 8pm and everyone m is welcome to be there.

The meetings take the form of a sing song accompanied by musicians and there is also an opportunity for anyone attending to give a solo as well.

Anyone interested in joining or seeking further information can email Ray at [email protected] MARKET SUCCESS. With the East Leake Christmas Market earlier this month being another successful festive event it confirmed the effectiveness of the parish council's programme to introduce the regular event to the village programme of activities.

Since the introduction of the market, its popularity has grown tremendously and the number and variety of stalls continues to grow.

The parish council have given their thanks to the stall holders and traders who attend the market and who often remark on the warm atmosphere in the village and the friendliness of the people.

Add the council in a message to the event supporters: "They truly value your custom and support especially through another tough year."

The council are also thanking the volunteer marshalls who readily give up their free time to lend a hand on market days. The market operates from 3pm to 8pm.

Sutton Bonington Mike Elliott 0115 937 6506

[email protected]

MUSIC SOCIETY. The popular and hugely successful Music Society based at the Sutton Bonington campus of Nottingham University -- its slogan is Led By Students, For All! - is open for membership to local residents as well as Uni students.

The group say they are a non-auditioned society, with members from the staffand student bodies of UoN, and members of the community from the areas surrounding Sutton Bonington.

"Become a member to join our ensembles, access our Private Music Room and join in with socials!" is their message to thew students and the general public.

They run four official ensembles, with weekly rehearsals for each group all year round and say they also run lots of different types of socials, with a wide range of performance opportunities, including Open Mic Nights, Jazz in the Barn, a Christmas Concert, Songs in Spring, Carol Services, Farmers' Market, Dining Ins and more!

The message sent out by the Group is "Get involved" adding that you play an instrument, or like singing, get in touch on Facebook, or with committee or conductors and follow their Facebook page for updates on concert dates and other exciting news!

SCHOOL ADMISSIONS. Admissions for a full time place at Sutton Bonington Primary School are governed by the local authority, Nottinghamshire County Council and parents need to apply directly to Nottinghamshire County Council to request a place at the school.

Please contact the school office on 01509 672661 if you would like further information, or to request a visit prior to application. A copy of the determined admission arrangements for 2023-2024 is available at: https://www.nottinghamshire. gov.uk/media/4320509/ admissionarrangements202324. pdf TENNIS CLUB. Despite weather problems that exist each Winter causing difficulties

for some sports and sports clubs, Sutton Bonington tennis club still play all year round on their LED floodlit courts and make a success of it as well.

The club say they are continuing the popular Monday group coaching sessions, which are for various age groups including adults, with all standards welcome, as well as two junior sessions every Saturday between 9.30 and 10.30 for under-nine's and 10-30- to 11.30 and players ten years and over. Further information on the sessions can be obtained from Jo at [email protected] The club also hold weekly social club evenings as well as plenty of opportunity for team tennis, with lots of fixtures continuing through the winter months. Contact here for information is Josh at ash. [email protected] or drop into the club on a Tuesday evening.

ADVENT FAIR. The Advent Fair held at Sutton Bonington St

Michaesl Church held earlier this month raised a profit of PS760 for funds.

The event,. held in the church, included a raffle, a bric a Brac stall; and others selling sweets, toys, tombola, cakes, Christmas cards and books. Alcohol free mulled wine and mince pies were also on offer as well as soup and rolls.

An illustrated history of the church was on display and drew interest from many of the visitors.

SCHOOL OPEN DAY. Sutton Bonington Primary School welcomed a good number of visitors last month for its Open Day morning when visitors were able to visit each classroom and learn about the curriculum and the enrichment activities that the school offers its pupils, including the Forest School, extra-curricular activities, pastoral care, having a vibrant PTA and good community links and on site independently run both before and after school provision and a buddy system to welcome new starters.

DISPESNSARY CLOSURE. The Village Health Group covering Sutton Bonington have announced the closure of dispensary services in the village.

The group, in a statement to the village, say they have taken the difficult decision to stop providing dispensary services from their premises in Sutton Bonington and have notified the National Health Service the system will cease as from Friday January 27 in the New Year.

Village residents and patients who use the current system can obtain more information on how to get their prescription from a pharmacy of their choice or nominate the pharmacy which they would like to dispense their electronic prescriptions by visiting a special link that has been set up at https://www.nhs-app/ nhs-app-help-and-support/ presriptions-in-the-nhs-app/ nominating-a-pharmacy or by visiting the health group website at www.villagehealthgroup.co.uk The Health Group say they would like to wish all of their patients and staffa very Merry Christmas and a Happy New Year MEMORIAL SERVICE. After a break of three years because of the coronavirus situation, Sutton Bonington St Anne's church were able earlier this month to stage its popular Memorial Service which again included a time for family and friends to light a candle in memory of a loved one.

Tea and biscuits were served after the service at which a total of 88 candles were lit.

Kegworth Mike Elliott 0115 937 6506 [email protected]

CHRISTMAS MARKET. Kegworth's festive season got offto a fine start thanks to the success of the Christmas Market held in what was a busy Market Place with several hundred people turning out to support the annual event.

The four hours of entertainment that was provided on the day began soon after lunch with many varied attractons, including the tradiional ceremony to switch on the village centre

festive lights.

Youngsters took opportnity of a visit to Santa's Grotto

while the adults had plenty of opportuniit to look round the stalsl offeriong food, drinks and general festive and other festive shopping.

Residents were invited to go down to the Market Place to hear the West Bridgford School band playing next to the village Christmas Tree., and they did in their numbers.

Another of the attractions was the annual appearance of two live reindeer - Boris and Mischa -- and then some 90 minutes later of Father Christmas. Kegworth Primary School were singing at 4.00 leading up to the tree lights ceremony 15 minutes later.

There were round 25 sideshows and stalls - outside Oaklands, Market Place and behind Soar Trading - supporting the local shops and between them creating a friendly and super festive atmosphere for the visitors to and around the Market Place.

The Days attractions and Market opened at 1pm festive music and an hour later the West Bridgford High School Band put in their contribution to herald the arrival of Father Christmas and kept playing in stages for nearly two hours. And with darkness looming children from the Primary School were back on scene to sing again to herald the festive tree lighting, followed by carols to music from the Band. Bells at the Parish church began ringing just before the market ended.

SCHOOL UPDATE. Confirmation has been given that the new school being built on Rempstone Road at East Leake to help provide much needed spaces for the influx of new scholars as the village continues to grow should be open in September 2023.

It is understood the new provision will be costing in the region of PS13million and will provide places for 210 primary school children along with a 26-place nursery.

In recent years

development of new housing in the village has outstripped what is available as far as school places go, and the extra accommodation need has been acknowledged by both Notts County Council and Rushcliffe Borough Council.

Without additional provision, dozens of parents have feared their children would not be able to be accommodated for schooling purposes in their own village and would have to travel to school elsewhere.

The Rempstone road development is not the only new schooling provision currently on the cards, and Rushcliffe Borough Council have given their support for a temporary school 'village' which is due to open in September next year, again to meet the growing need for education places in East Leake. This temporary site will accommodate an initial

120 children.

At their recent meeting Notts County Council's policy committee confirmed the costings and the timeframe for the new permanent school and Coun. Keith Girling, the conservative chairman of the economic development and asset management committee, told members that the school will cost PS13.62 million to provide. He admitted to the committee that current increasing demands for primary school places, the existing schools cannot meet what is required.

This will be split between Section 106 developer contributions from the property companies on Rempstone Road, and through support from the Government's Basic Needs programme The proposed the new primary school will be built on land provided by two housing developers as part of their Section 106 contributions, and to meet the demand it is proposed accommodation is provided in the temporary village from September next year..

It is understood a community group will be set up in Rushcliffe to share its views on the school's development and it will It will support the integration of the primary school into Rushcliffe's network of existing sites, many of which are rated good and outstanding by Ofsted.

Normanton on Soar

CHRISTMAS IN NORMANTON ON SOAR. It was good to be able to hold a number of events over the Christmas period.

First of all, there was an excellent turn-out for the switching-on of the Normanton on Soar Christmas Lights, with carols sung at the old conker tree and mulled wine and mince pies being enjoyed by all. A week later, the Candlelit Christmas Concert was held in St James Church and the following day, the Village and Soar Boating Club Carol Service took place, led by The Revd Canon Michael Knight. At this service, a cheque was presented to Wenlo Riding for the Disabled Group (based here in the village), which was St James Charity of the Year 2022. On Christmas Day, a service of Holy Communion was once again led by The Revd Canon Michael Knight.

NEW YEAR SERVICES AT ST JAMES' CHURCH. On New Year's Day, Jan Bonser will lead us in a service of Morning Prayer to greet the New Year.

Willoughby on the Wolds

BREAKFAST. The popular Willoughby on the Wolds Breakfast event returns to the village hall on Sunday January 8. Food will be served between 9.30and 11.30am and everyone will be welcome.

Long Whatton

and Diseworth CHURCH DEAL FALLS THROUGH. Long Whatton Methodist Church has now been closed for two years, although Methodism in the village can be traced back over 200 years. Efforts to purchase the building on behalf of the village have fallen through.

The 19th Century saw a huge rise in the number of practising Methodists, or Wesleyans as they were called, across England and the tiny villages in North West Leicestershire were no exception.

In 1829 a Chapel was built in Long Whatton behind the site of the existing church and throughout the century a large congregation was built up with a flourishing Sunday School. Church accounts record expenses for music for their Anniversaries, Clothing Clubs, Sunday School prizes, printing of hymn sheets etc. However by 1900 the little chapel was in a state of serious disrepair and an appeal was made for a new church describing the current premises as 'an old square dilapidated Chapel absolutely destitute of vestry and schoolroom and almost lost up a well nigh inaccessible yard.

A site on the Main Street was found and ambitious plans drawn up. An appeal was made throughout the Methodist circuit for subscriptions, a Great Circuit Bazaar was organised and with the sale of the existing chapel and land the funds were raised On 4th October 1911 the President of the Conference, Rev. John Hornabrook from Central Building, Manchester signed the official form for the sale of the old chapel and site with the proviso that 'of taking all possible means against being used for the manufacture or sale of intoxicating liquors, or as a theatre or dancing or music hall.'

The Early Days Methodism in Long

Whatton can be traced back over 200 years. The 19th Century saw a huge rise in the number of practising Methodists, or Wesleyans as they were called, across England and the tiny villages in North West Leicestershire were no exception.

In 1829 a Chapel was built in Long Whatton behind the site of the existing church and throughout the century a large congregation was built up with a flourishing Sun-day School. Church accounts record expenses for music for their Anniversaries, Clothing Clubs, Sunday School prizes, printing of hymn sheets etc. However by 1900 the little chapel was in a state of serious disrepair and an appeal was made for a new church describing the current premises as 'an old square dilapidated Chapel absolutely destitute of vestry and schoolroom and almost lost up a well nigh inaccessible yard.

A site on the Main Street was found and ambitious plans drawn up. An appeal was made throughout the Methodist circuit for subscriptions, a Great Circuit Bazaar was organised and with the sale of the existing chapel and land the funds were raised On 4th October 1911 the President of the Conference, Rev. John Hornabrook from Central Building, Manchester signed the official form for the sale of the old chapel and site with the proviso that 'of taking all possible means against being used for the manufacture or sale of intoxicating liquors, or as a theatre or dancing or music hall.'

In 1912 the new Church with Entrance Vestibule, organ, vestry, kitchen and large schoolroom was built to the delight of the congregation, the village and the Circuit. The Twentieth Century saw the

continuation of a very successful Sunday School with records showing large numbers of young people registering each week. Electricity was extended through the Church,

alterations took place to include a new kitchen and toilets and generally improve the building. The Church played its part during the WW2. A minute from the Annual Trustees meeting of February 1940 notes 'proposed and seconded, that Caretaker should be increased by one shilling per week during winter months on account of schoolroom being Ambulance fort and First Aid post.

By 1946 it was decided to raise the caretaker's salary by PS2 making it PS12.0.0 per year.

There are many references of thanks to church members who performed the task of organ blowing and in November 1948 the Trustees 'resolved in view of the generous gift of PS105 by Mr Eli Lester for the purposes of providing an electric blower for the organ, the trustees accepted unanimously the estimate for cleaning and making necessary improvements to the organ. It was resolved that a small plate be placed on the organ with words stating that the organ blower was the personal gift of Mr Eli Lester in memory of his mother and father'.

In January 1953 a request was made to rent the Schoolroom every Tuesday afternoon for a Darby and Joan Club meeting. The trustees decided to check the Standing Orders of the Methodist Church as regards 'what could and could not be done'. Unfortunately by the Annual Meeting following year it was noted that the Darby and Joan Club had 'fixed up their premises elsewhere' The meeting the following year, Mr Boultbee was asked at a fee of five shillings a

week to do the stoking of the boiler.

In 1955 water had been laid on and the copper in the scullery removed and an electric copper installed. New sink and draining board, also electric fire in the vestry.

In 1957 the Methodist Church balance sheet was 'in a favourable position' and

agreed that PS1.0.0 should be given towards extensions at Trinity Hall Girls School.

In 1961 it was resolved that the Trust should be renewed and new trustees added to the existing list bringing the number to 20. A year later a committee was formed to look into the 'various jobs that should be done to the chapel and material to be obtained and inquiries made of work to be carried out before the 50th Anniversary. Quotations were received for cleaning walls of the Chapel and the Sunday School, painting of ceilings and exterior cleaning.

The organ was removed from the front of the Chapel to the side. Following the Anniversary Celebration on 25th August 1962 the trustees recorded 'Everyone was very pleased with the result of the Chapel Anniversary both spiritually and financially and for the large attendances for the Services and the approximate figure of 100 for tea in the National School'.

In 2012 the Church celebrated the Centenary of the Church with an exhibition and tea.

The parish council say as previously reported the Long Whatton Methodist Church, based on its great historical significance within the village, was registered as an Asset of Community Value (ACV). This meant that once the asset was put up for sale, a notification had to be made to trigger the legal procedure attached to this policy.

However, as this didn't

happen first time around the Long Whatton Community Association (CA) and Long Whatton and Diseworth Parish Council (PC) were given the opportunity to review their project to buy it and rebid for the purchase; the ACV rules gave the community six months for the process to acquire the asset.

Obtaining the building for the benefit of the people of the parish for community use in perpetuity was considered important enough for the CA and PC to work together on a new bid. A plan was agreed and once permission was received from the Secretary of State a revised offer was tabled to the Selling Agent.

A council spokesman said: "Unfortunately, the new offer, that was more than double that previous put forward, was again unsuccessful. We have been advised that although the CA/PC bid was positive the community charity law dictates that the building had to be sold to the highest bidder, irrespective of any other consideration.

"On behalf of everyone involved, I would just like to thank you all for your continued help, support and efforts during this lengthy process; it's not the outcome we wanted, but we are sure the team could not have done more on your behalf."

Gotham BIRD PLEA. Gotham parish council have put out a message to residents to remember to put out food for the birds during spells of cold and bad weather.

In the message they say the birds need a reliable supply of supplementary food to get through the difficult winter months, so try to ensure you offer them a regular delivery service, refill feeders promptly and twice a day if required when the weather is really bad.

The appeal says: "When the

weather is really bad, birds need to refuel quickly after very snowy conditions " SCOUTS. Members oi the 1st Gotham Scout troop Explorer Scouts are working towards their Bronze Duke of Edinburgh Awards.

Tehre are four key activities in the DoE Challenge, volunteering is aimed at giving back to the community, physical for building endurance, Skills learning to

adapt to new challenges, expedition is for practical experience in outdoor activities.

Widmerpool

CLERK APPOINTED. Emma Goodman of Tollerton is the new clerk of Widmerpool Parish Council. She can be contacted by email at clerk@ widmerpool.parish.email

Mountsorrel MEETINGS OF THE PARISH COUNCIL/COMMITTEES: Monday January 9, 2023 Planning & Policy committee meeting at 7pm at the Memorial Centre, Monday January 16: Full Council meeting (including Budget setting) at 7pm in the Parish Room; Monday January 23: Projects & Amenities committee meeting at 7pm in the Parish Room EVENTS AT MOUNTSORREL MEMORIAL

CENTRE (MMC): Friday January 27, 2023: Motown, Soul & Northern Soul - PS8.

For more information about these events please contact the MMC by telephone 0116 230 4877 or email reception@ mountsorrelmc.co.uk

Wysall CORONATION PLANS. Plans are being formulated by the village Social Committee at Wysall for a Picnic in the Park event in May to celebrate the Coronation of King Charles III.

CAPTION(S):

Long Whatton Methodist Church.

Note(s):

ISSN: 0966-1948

Reports - Telecommunication - ENISA

Publication date: October 19, 2023 85633 mots

Threat Landscape - Download - fullReport

161 pages

Please note : This extract may not display a well formed paragraph

... EUROPEAN UNION AGENCY FOR CYBERSECURITY OCTOBER 2023 ENISA THREAT LANDSCAPE 2023 July 2022 to June 2023 ENISA THREAT LANDSCAPE 2023 October 2023 1 ABOUT ENISA The European Union Agency for Cybersecurity...

Full report:
https://www.enisa.europa.eu/publications/enisa-threat-landscape-2023/@@download/fullReport
Sud Ouest
Bordeaux, mercredi 25 octobre 1989 3630 mots, p. 22
Aussi paru dans

23 juin 2000 | - | Les Affaires
2 juin 2004 | - | Le Soir
1 juin 2005 | - | Journal: Air and Waste Management Association
1 février 2006 | - | Le Soir
30 mai 2006 | - | Marketwired (english)
6 mars 2008 | -
30 juillet 2010 | - | Les Echos - Avis financiers (english) Les Echos - Avis financiers (français)
6 octobre 2010 | - | Briefing - Stocks
12 mai 2011 | - | Le Point
3 octobre 2011 | - | Canada NewsWire (english)
27 février 2013 | - | Reports - Banks and Financial Institutions
19 mai 2018 | - | Web sites - Health and Fitness / Activité physique, santé

[M CUB SPORTS SURF/SAMÉRIGNAC SPORTS...]

M CUB SPORTS SURF/SAMÉRIGNAC SPORTS DE SALLE /TSA BORDEAUX Caroline Faucher : la nouvelle vague * Les talents de la glisse sur les vagues ne sont pas tous de BiscaiTosse ou de Lacanau. La preuve Retrouver le frémissement des Peupliers Grande soirée de volley et de basket samedi soir, a u Palais des sports, où les Jeunes de SaintAugustin espèrent retrouver l'ambiance de leur salle fétiche Hockey sur gazon: coupe latine àRocquevieÙe S2-2018 Ver P our les JSA Bordeaux, la saison 1988-1989 avait été celle de la Coupe d'Europe.

La suivante sera celle des gros travaux. L'indispensable réfection de la salle des Peupliers a, en effet, contraint le «patro» de Saint-Augustin à émigrer pour une année au Palais des sports, qu'il s'agisse des volleyeurs ou des basketteurs.)romotion et d'organisation pour eur grande soirée de samedi, qui comprendra, à 17 heures, le match de volley contre Grenoble (vicechampion de France) et, après un intermède musical proposé par un groupe de chanteurs basques, une rencontre de basket de Nationale 2 entre les Bordelais et le leader actuel, la CRO Lyon.

Des actions ont été menées en milieu scolaire pour rameuter de jeunes spectateurs. Des navettes seront prévues pour emmener les supporters au Palais des sports... et es ramener. Un affichage généreux a été organisé pour sensibiliser les Bordelais. «On veut montrer, à cette occasion, ce qu'on est capables de faire», dit Jean-Louis David, «et je suis sûr qu'il y aura • beaucoup de monde au Palais des sports». En fait, le programme commencera à 16 heures et s'achèvera vers 22 heures. Du coup, c'est tout le quartier Victor-Hugo qui deviendra la banlieue de Saint-Augustin.

A défaut de bâtir des villes à la campagne, ' pourquoi ne pas transférer les banlieues au centre ville? m La Fédération française de hoil ckey sur gazon a confié au Comit d'Aquitaine de hockey, en étroit collaboration avec les Girondin de Bordeaux omnisports l'organi sation de la Coupe latine de hq ck6y. ""^^ean-Marie Royer et Caroline Faucher ' I " a nouvelle vague du surf français I l est arrivée ! Elle se nomme Caroline Faucher. Agée de 22 ans, licenciée au club mérignacais depuis six années meilleure métropolitaine, •ette ieune fille d'origine bordelaise •n'en est plus à son premier coup cl'éclat.

Mais, cette fois, la sélection yiour les championnats du monde est (Photo Nicole Vigne) '"'"c'est à Veiro, au Portugal, que se déroulaient les derniers chanipioniiats d'Europe de surf. Une dizaine de D'une agilité remarquable, il la uavs représentés, une vingtaine de compare à un chat. Vitesse de réacoarticipants et une place de demi^fition, d'exécution, souplesse, vivacité naliste pour cette première sélection sont ses points forts. Tout ceci se en équipe de France. Pas mal direz- • peaufine au fil des entraînements vous ' Et pourtant, aux dires de 1 inté- avec un programme hivernal chargé.

ressée el e aurait pu mieux faire. Une , Premier point, travailler la condiremarque d'ailleurs appuyée par tion physique. C'est en piscine qu'elle {Jean-Marie Royer, l'entraîneur. s'attelle aux nombreux exercices : enLa tête sur les épaules, baronne durance, chrono, apnée, épreuve de Faucher sait analyser ses Victoires et sauvetage, etc. Deuxième point, la ses défaites et replacer chacune pratique du sport. Là, le décor naturel d'elles dans son contexte. Elle avoue des côtes atlantiques guidera le desgentiment, un sourire au coin des lè- sein de ses inspirations.

vres n'avoir jamais surfé aux côtés Quant à son avenir, Jean-Louis des meilleures : les Californiennes, les Royer le voit et il le dit clairement : Hawaïennes... « On vise, d'ici à quatre, cinq ans, la Le rêve de tout surfeur n est-il pas la Californie ? Mais là, c'est une autre plus haute distinction au championnat du monde, tout en étant conscient histoire. Sans ressource puisque sans du travai à accomplir. » travail hormis quelques leçons de Une phrase qui en dit long sur la surf çà et là, elle attend impatiemmotivation et la détermination de ment le coup de pouce qui lui permetcette équipe où maître et élève s'abantra - peut-être - de pousser son tadonnent dans une complicité phénolent hors des frontières européennes.

ménale. Pour l'heure, les championnats Le surf compte de nombreux licend'Europe sont loin et le maître parle dt' son élève, de l'avenir avec les yeux ciés. Rares sont ceux qui atteignent un niveau international. Caroline d'an professionnel. Président de la ligue d Aquitaine de Faucher, elle, fait partie de ces sursu'f mais aussi entraîneur du club douées de l'équilibre qui n'ont pas fini de nous étonner. mcrignacais, surfeur depuis plus de dix années avec un titre de champion de France vétéran, Jean-Marie Royer, bénévole dans le cas présent, sait de quoi il parle : « Ce qui fait actuellement la différence entre Caroline et les autres filles, c'est l'expérience.

A 22 ans, elle se mesure à des surfeuses bien plus âgées qu'elle (25-30 ans). Celles-ci ont davantage de pratique et donc bien souvent un mental forge. Sur ce dernier point, Caroline reste fragile. » Malheureusement, ce transfert a laissé apparaître un certain déficit en spectateurs : «On s'y attendait, dit Jean-Louis David, car les gens répugnent à prendre leur voiture, sachant qu'ils ne peuvent pas se garer facilement au centre ville. Le Palais des sports est très beau, mais il paraît un peu froid à côté des Peupliers et les gens ne s'y sentent pas autant chez eux.

» L'impératif est donc clair : retrouver un public, car, comme le dit Jean-Louis David, «avoir une équipe de haut niveau devant 200 spectateurs est un non-sens. Je veux de la fête. Je ne refuserai jamais l'entrée à un groupe de musiciens.» Dans cette perspective, les JSA ont effectué un gros travail de On peut compter sur Michel Haustrate pour animer le Palais des sports de Bordeaux (Photo Christian) COURSE PEDESTRE /lO KILOMÈTRES DE PESSAC C'est la première édition d'uJ compétition internationale pou les équipes nationales de jeune de moins de 16 ans et de moins d 18 ans qui réunira les nations sul vantes : Espagne, Italie, Portugai France.

' La compétition se déroulera su les infrastructures des Girondin de Bordeaux au domaines de Roc quevielle, avenue Marcel-Da^ sault, à Mérignac, sortie rocad n" 10, les 2,3 et 4 novembre. A cette occasion le club inaugu rera son terrain synthétique sabl qui constitue le premier investis sèment de ce type en Aquitaine. Cette réalisation, rendue possi ble, grâce au soutien des munici palités de Bordeaux, de Mérign? et du Conseil général permettr que se disputent sans interruf tion sur les trois journées 16 ref contres internationales.

Les équipes seront à pied d'œi vre à Bordeaux dès le lundi pou les ultimes entraînements et n groupent 160 jeunes sélectionn* des quatre nations participantes, L'hébergement est assuré par 1 club des Girondins et les hôtels,d Mérignac. Battu parLingard sur les 16 kilomètres de Blanquefort, de Andrade avait consenti beaucoup d'efforts, la veille, pour venir à bout de Belachmi sur les 10 kilomètres de Pessac Classement. - 1. De Andrade (SBUC), 30 mn 43 s; 2. Belachmi (SBUC), 31 mn 06 s; 3. Fabre (SAM), 31 mn 28 s; 4.

Hélène (Mezidon), 31 mn 31 s; 5. Benne (ASPTT Bordeaux), 31 mn 39 s; 6. Schalk (ACIF), 31 mn 50 s; 7. Brilland (ASPTT Bordeaux), 32 mn 09 s; 8. Monnier (ASCPA), 32 mn 55 s; 9. Gâche (A. Campus), 33 mn 01 s; 10. Malmoustie (ASPTT Bordeaux), 33 mn 07 s. 11. Jaze (IBM), 33 mn 09 s; 12. Amilhat (Sogerma); 13. Alfieri (NL); 14. Ningre (SBUC); 15. Wery (S. Langon); 16. Ozanne (IBM); 17. Ducos (S. Langon); 18. Caboche (NL); 19. Bonnel (Carbon-Blanc); 20. Renard (Pompiers), 34 mn 31 s 9. 21. Prijac (SCO); 22. Blanchemain (ASSM); 23.

Vignes (NL); 24. Lavallée (CAB); 25. Pedros (Serta); 26. Rouannet (ASPTT Bordeaux); 27. Pescay (S. Langon); 28. Faure (CHS); 29. Dagherir (ASPTT Bordeaux); 30. Weber (CAV),35mn25s. 31. Peronet (NL); 32. Carrère (EG); 33. Prime (ASCPA); 34. Poirier (NL); 35. Bordessoule (NL); 36. Vial (S. Langon); 37. Queneville (ASCPA); 38. Arnaud (S. Langon); 39. Thepaud (NL); 40. Girardaud (NL), 35mn 47 s. 41. Duverdier (SAM); 42. Beaugeard (NL); 43. Le Prévôt (AS Police); 44. Loreinte (ASCPA); 45. Dresco (ASPTT Bordeaux); 46.

Martin (NL); 47. Boiteaud (NL); 48. Biraud fNL): 49. Dugrillon (USCC); 50. Humeau (ASPTT Bordeaux), 36 mn 42 s. « 51. Gouin (S. Langon); 52. Maury (NL); 53. Desages (S. Langon); 54. Lopez-Onate (ASCPA); 55. Malard (ASPTT Bordeaux); 56. Vergne (NL); 57. Schmalz (NL); 58. Lougare (NL); 59. Guyonvarch (Dassault); 60. Perriat (ASPTT Bordeaux), 37 mn 26 s. 61. Haller (NL); 62. Dulau (NL); 68. Deyres (Biscarrosse); 64. Brunet (NL); 65. Sanchez (Bayonne); 66. Bessière (ESB); 67. La Brèze (CHS); 68. Bedin (CR Bordeaux); 69.

Ranson (NL); 70. Boucrot (A. Campus), 37 mn 59 s. 71. Viault (ASCPA); 72. Dubost (NL); 73. Brachet (A. Campus); 74. Lacoste (NL); 75. Daban (USCC); 76. Martinez (NL); 77. Galiana (ASCPA); 78. Léon (ASCPA); 79. Soulard (NL); 80. Castaing (Lyonnaise des eaux), 38 mn 25 s. 81. Santiago (NL); 82. TaiUard (ASCPA); 83. Fautre (AS Police); 84. Bremond (IBM); 85. Maniy (ASCPA); 86. Couleau (CAM); 87. Cheyssou (NL); 88. Bridet (NL); 89. Lozes (CHS); 90. Macabiau (ASPTT Bordeaux), 38 mn 52 s. 91. Dupouy (ESB); 92. Lammar (NL); 93.

Félix (NL); 94. Royer (NL); 95. Valeze (ASPTT Bordeaux); 96.01livier. (A. Campus); 97. Suzin (USCREI); 98. Vergnes (COR); 99. Rul166. Vaidie (NL), 167. Saintanon (IBM), 168. Desperez (NL), 169. Seigne (IBM), 170. Eychenne (NL), 43 mn 10 s. 171. Garros (NL), 172. Giroux (NL), 121. Limoges (NL), 122. Namm 173. Riere (IBM), 174. Hutzli (NL), (NL), 123. Guerin (USCC), 124. Marc 175. Lajrrige (CMO/Bass.), 176. Les(AS Police), 125. Vallée (CHS), 126. tage (A. Campus), 177. Boussioux David (ASPTT Bx), 127 Hicaube (NL), 178.

Menard (NL), 179. Lagar(ASPTT Bx), 128. Vaugrenar (ASAC), dère (SOGERMA). 180. Dorlanne 129. Rodrigues (A. Campus), 130. (ASCPA), 43 mn 45 s. 181. Villeneuve (NL), 182. Zugasti Garros (CAM), 40 mn 53 s. (NL), 183. Dubois (CMO. Bas.), 184. 131. Bigone (NL), 132. Lacau (NL), Venayre (USCC), 185. Sanchez 133. Palacios (NL), 134. Bonnafous (ASCF), 186. Froissart (NL), 187. (ASPA), 135. Jaume (NL), 136. Jime- Rouzeau (NL), 188. Escudero (NL), nez (CAM), 137. Dambrun (ASCPA), 190.Larrue(COAC),44mnl4s. 138. Pizot (NL), 139.

Viegas (NL); 140. 191. Panicaut (NL), 192. Riedweg Champux{IBM),41mn25s. (NL), 193. Lepretre (NL), 194. Bourre141. Fernandez (NL), 142. Esquinét tere (ASCPA), 195. Cassou (NL), 196. (NL), 142 bis. Duluc (A. Campus), 143. Duval (CHS), 197. Boissou (ASCPA), Taris (NL), 144. Gutluck (ASPTT Bs), 198. Lemire (CLAS), 199. Romestan Léandre de Andrade (SBUC). 145. Cailliard (SAM), 146. Bouyeres (SISF), 200. Bezarion (ASPTT Bs), (NL), 147. Irasque (AGA), 148. Lom- 44 mn 55 s. (Cliché «Sud-Ouest») bard (UST), 149. Donate (NL), 150.

Pe201. Mondot (IBM), 202. Doulignac ret (Dassault), 42 mn 02 s. (A. Campus), 203. Pittion (NL), 204. lier (CHS); 100. Sajous (IBM), 39 mn. 151. Cresson (SANOFI), 152. Benoit Laurent (NL), 205. Soulard (NL), 206. 27 s. Simon (NL), 207. Desfontaine (NL), 101. Castaing (NL); 102. Ghislemi.(IBM), 153. Duconge (NL), 154. Ma- 208. B e r t r a n d (Dassault), 209. (AS Police); 103. Houille (A. Campus); zeau (USC), 155. Faure (CHS), 156. Comblât (NL), 210. Auguet (NL), 104. Fourcade (CLAS); 105. Barbot Ebrard (NL), 157.

Bonnin (CHS), 158. 45 mn 31 s. tASCPA); 106. Montessuy (NL); Larche (CAM), 159. Habault (NL), 211. Dix (NL), 213. Domenge (NL), 107. Degraves (NL); 108. Jimenez (So- 160. Bernard (Dassault), 42 mn 32 s. 213. Bouyer (NL), 214. Blin (CHS), germa); 109. Ronchon (NL); 110. Car161. Lecomte (ASCPA), 162. Nicol- 215. Fontaine (Avia Club), 216. Guiniz ricart (A. Campus), 39 mn 43 s. leau (NL), 163. Barbazange (SAM), (NL), 217. Pichlak (NL), 218. Foulou 111. Boucherie (NL), 112. Taris 164. Taris (NL), 165. Denanteau (NL), (ASCPA), 219.

Foulou (ASCPA). (NL), 113. Bes (NL), 114. Manzanedo (NL), 115. Bancon (NL), 116. Sandre (NL), 117. Donadieu (ASCPA), 118. Morello (NL), 119. Treguer (IBM), 120. Durin(IBM),40mn22s. De Andrande décroche Belachmi Sylvie Lagrange 01 encore Sylvie Lagrange' (Photo «s-0» ARTS MARTIAUX /SKC J«as Le mini-Sochin aussi Le Sochin Karaté Club s'ouvre maintenant aux enfantsde 4 à 13 ans COURSE PÉDESTRE /lO KILOMÈTRES DE CANÉTAN Michel Benne comme un junior Les vétérans se portent bien. A Canéjan, c'est Michel Benne qui s'est imposé devantJean-Pierre VoUe Classement : 1.

Benne (ASPTT), 32 mn 03; 2. Voile (Oxygène); 3. Lelièvre (ESCO Saint-Lazaire); 4. Filhos (Santé navale); 5, Amilhat (SOGERMAJ; 6. Jaze (OBM), à 1 mn 50; 7. Toizat (Sanofi); 8. Burgaud (ASPTI); 9. Wery (Langon); 10. Ozanne (IBM), à 2mn05. L e s profs du Sochin Karaté-Club (Photo « Sud-Ouest ») 11. Duflade (Langon); 12. Dumesnil e centre d'arts martiaux Sochin, centre. Maître Hann Chun Tec, 5' dan, (CHS); 13. Diaz (ASPTT); 14. Rufet après trois saisons d'existence, est assistant de maître Lee Kwong (CAB); 15.

Fresquet (CAB); 16. Re"""possède un encadrement exception- Young, 8' dan, responsable national nault (SICF); 17. Blanchemain (Saint" - nel. M. Man Hu, diplômé de l'acadé- du tae kwon do en France. Il effectue Médard); 18. Lavaud (CAB); 19. Pei>u fi mie des arts martiaux de Pékin ensei- un stage national actuellement à Bor- chambert (Langon); 20. Rouanet gne le kung-fu, le tai-chi, le tchi-kong deaux. Tous les pratiquants de cette (ASPTT), à 3 mn 38. 21. Faure (CHS); 22. Hélène (Mezidans la tradition d'origine.

Pour le discipline de Bordeaux et e la région kendo, Jean-Pierre Labiru, 3- dan, 2" peuvent bénéficier de son enseigne- don); 23. Roux (SOGERMA); 24. Caboche (NL); 25. Dagherir (ASPDD; 26. dan de iai, instructeur fédéral. ment. Sauboua (ACBL); 27. Boutin (CAB); La boxe américaine est représentée 28. Rahmani (Avia); 29. Peny (Avia); Pour le karaté, Gérard Claverie, - ceinture noire, 4' dan d'Etat 2-degré, par Christian Antonioti, 2" degré, pra- 29, Peny (Avia); 30. Lagard (Avia), à directeur de l'école des cadres du Sud- tiquant complet, qui sait donner à 4mn08.

Ouest dont l'enseignement est issu cette discip ine un caractère at31. Queneville (ASCPA); 32. Godedes maîtres japonais Shirai, Kase, trayant grâce à un enseignement pro- froid (UAGM); 33. Jordy (CAB); 34. gressif et adapté à tous. Enoeda 8' dan, résidant en Europe, Clerc (Avia); 35. Mensan (CAM); 36. auprès desquels celui-ci travaille réAu Sochin, cette année, une innova- Viala (Langon); 37. Bekkouche (Avia); gulièrement. tion : la création du • mini-Sochin » ré- 38. bats (NL); 39. Ducos (Langon); 40. Une section d'aïkido fonctionne, servé aux enfants de 4 à 13 ans.

L'ex- Beaugeard (NL), à 4 mn 49. 41. Garcia (Avia); 42. Girardeau animée par un jeune professeur, élève périence de l'année passée, avec de maître Tissier. Caroline Jardin, ceinture noire, 2* (NL); 43. Maury (NL); 44. Penicaud dan, diplômée d'État, s'est révélée en- (Talence); 45. Carrère (Gironde); 46. Là venue de maître Hann Chun Tec courageante. Cette section de judo Demonti (NL); 47, Birginie (Cenon); revêt un caractère exceptionnel dans compte maintenant 35 tout-petits, ré- 48, HUmeau (ASPTT); 49. Cure le domaine du tae kwon do pour le Sopartis dans plusieurs classes, qui (Saint-Jean-de-Luz); 50.

Biriiud (NL), chin et notre région. Ce maître coréen à5mn30. viennent enthousiastes s'initier au s'est installé à Bordeaux pour dispen51. Ramillon (Gironde); fi2. Tamajudo sur le grand tatami du Sochin. ser son enseignement dans le cadre du gnan (Bazas); 53, Perriat (ASPTT); 54. Vergne (NL); 55. J u m e a u (ASPH); 56. Haller (NL); 57. Daban (Canéjan); 58. Schmalz (NL); 59. Ornon (NL); 60. Wery (Langon), à 6mnl4. 61. Pillet (NL); 62. Brunet (NL); 63. Mangeret (SPIRIDON); '64. Zeddam (ASPTT); 65. Rauzet (Anonymes); 66.

Rousse (NL); 67. Soulard (NL); 68. Guyonvarch (Dassault); 69. Labourche (Bazas), à6mn 48. 71. Mourigue (IBM); 72. Perrière (NL); 73. Martinez (NL); 74. LopezOnate (NL); 75. Coas Rouges; 76. Benedicto (SISF): 77. Bremond (IBM); 78. Destaillac (NL); 79. (îaros (CAM); Chaque hmdi! 80. CastainK(Avia), à 7 mn 16. 81. Aliker (CAB); 82. Durand (CAB); 83, Valeze (ASPTT); 84. Favres (Sanofi); 85. Rouffet (NL); 86. Treguier (IBM); 87. Léon (SOGERMA); 88. Couleau (CAM); 89. Chalon (CCAB); 90. Roquecave (NL), à7mn31. 91.

Robert (NL); 92. Bresolin (NL); 93. Laboudigue (USCRD); 94. Gallianau (Avia); 95. Debes (NLJ; 96, Caillou (Avia); 98. Bottais (Pompiers); 99. Bourdebaigt(NL). 100. Lucantis (NL), à 7 mn 50. 101. Courbaterre (Oxygène); 102. Coderc (Lectra); 103. Caffer (SISF); 104. Montessuy (NL); 105. Ollivier (SISF); 106. Boucherie (NL); 107. Mesnard (NL); 108. Fortin (NL); 109. Gimenez (SOGERMA), à 8 mn 17; 109 Lequeux(IBM),à8mnl7. 111. Manzanedo (NL); 112. Pujol (Avia); 113. Honorât (NL); 114. Sandre (NL); 114. Gavignaud (Avia); 115.

Benejat (CAB); 116. Ronchon (NL); 117. Laguillon (SISF); 118. Vaugrenard (ASAC); 119. Giegas (NL); 120. Lagauche(NL),à8mn40. (NM); 148. Latestère (Langon); 149. Labrouche (Bazas); 150. Goudeneige (IBM), à 9 mn 33. 151. Aurian (CACBO TRI); 152. Be, noit (IBM); 153. Chollon (NM); 154. Soulignac (Lestra); 155. Apert (Avia). • Aux championnats d'Aqu taine féminins de karaté-do (coi bats), à Pau, Sylvie Lagrange remporté une nouvelle fois le tit des plus de 60 kg. Dominant le karaté région depuis six ans, elle n'a pas trou d'opposition réellement à sa ha teur.

Nous lui avaons alors d mandé pourquoi continuer combattre au niveau de la ligui « Pour que d'autres filles accède au même niveau, nous confie Si vie. Si les compétitrices de nive; national se retirent des chai pionnats de ligue et de départ ment, les combattantes peu exp rimentées n'auront jama= l'occasion de nous rencontn; Avant d'aller aux championnat de France, il faut que les fill' s ' a g u e r r i s s e n t et trouve:| confiance en elles. Mon objeci est de les y encourager et j'arrêt ' rais le jour où ce message se passé.

» C'est une manière très démor trative de concevoir son rôle d'e traîneur et sa mission de dévelc pement du karaté-do féminin. 293995 I I Stage de voile à Bordeaux-Lac • Le centre de voile de Bc deaux-Lac organise, à l'attentic des jeunes de huit à dix-huit an un stage d'initiation ou de perfe tionnement à la pratique de voile (dériveurs ou catamaran jendant les vacances scolaires (a "Toussaint. Ce stage, de sept jours, en dem pension, de 9, heures à 17 heure ••!2a)')7 aura lieu du mercredi 25 octob: au vendredi 3 novembre 1989 (2 26 27, 30, 31 octobre, 2, 3 nover bre).

L PRÊT-A-PORTER FÉMININ 86, avenue du AAédoc LEVIGEAN 33320 EYSINES Sortie rocade n' 7 direcNon le Verdon LIQUIDATION TOTALE TOUT DOIT DISPARAITRE ROBE longue de soirée style haute couture bordée de paillettes et de strass, très chic Vente imposée par l'urgence d'un important stock de vêtements pour dames de haute qualité PUU EiGO fantaisie torsadé très belle qualité tUféïf 100% acrylique J i ^ AÉXt CHEMfSfERHAVFAIR manches longues, style habillé 50% coton, lOOf 50 % polyester.Ji^d50%polyester.....jm- I O T ŒElIttUHtKACHERINE ,1^ Michel Benne (ASPTT) 121.

Feyroux (NL); 122. Uurin (IBM); 123. Lepretre (NL); 124. Donadieu (ASCPA); 125. Houllier (anonymes); 126. Limoges (SISF); 127. Morello (NM); 128. Dubois (CAB); 129. Terrasson (Langon); 130. Anglade (ASSEP),à8mn55. 131. Suzin (USCRD); 132. Quere (IBM); 133, RAoul (SISF); 134. Vergnaud (NL); 135. Menant (NL); 136. David (ATSCAF); 137. Ramon (NM); 138. Gele (Lectra); 140 Marc (AS Police), à 9 mn2L 141. Robillard (ENGA); 142. Manyi (NL); 143. Hamm (NLM); 0144. Moreau (NL); 145. Guerin (SOGERMA); 146. Saintamon (NM); 147.

Mailfait ni Cahier "S" S D O ET U US LE SPORT DANS LE SUI>OUEST tous les résultats, tous les commentaires Le centre est agréé comme ce: tre de loisirs, sans hébergemer PIfil angora laine Les allocataires de la Caisse d's 100% viscose... JéeO fxis de cou belle qualité locations familiales bénéficie manches courtes, style large, 60% laine, 22% angora CAUUlN très moderne d'une réduction du prix de jou classique mode f ^Mf 18% polyamide.. JiSr élastislOO^o l9Af 100%co1on MT ilH née. polyester 0*8" U T JUPE plissée Pour tous renseignements i CHEMISIER SOUMERMANN longue taille unique très habillé, col drapé, broderie y | inscriptions, s'adresser au cent OUEODNtràs/eune style mode manches longues CTiOf p de voile de Bor(leaux-Lac, t< élastis5 %AF.

, 100% polyester.J95 U T JOO%polyester.>><5r. 56.50.95.53 (du lundi au vendrec 95%ocrylique...Jîfiflr de 9 heures à 12 heures et (ENSEMBIE juoe unie, /UPE cuir droite fantaisie 2 poches veste courte, col rond 14 heures à 18 h 30). RAIVnilQN JAMES sm très chic très mode, OACf ' très jeune à pinces 14ff)00%coton looxcoton..aflor ROBE tricot, col ras de cou TAIUEUR style CHANEL manches longues, très belle PUIfALON EVA PICOVSKI Le centre de voile de Boi jupe droite veste courte lualité, 20% laine, J/l^^ style mode à pinces t%tÈM.

§ deaux-Lac organise une prépar 8 0 % acrylique 100 % coton.jrf /OO 'm%hine J23eo2l2ff tion aux examens des permis (ROSE style manteau conduire les bateaux à moteur; style ample BIOUSON cuir très belle très actuelle, col velours mode manches, — Rivière, mercredi 15, ve qualité l4AAf 60 % viscose, dredi 17 et lundi 20 novemb: couple ample... IZTV 40 % polyester. j a f 9 W 7 -v-^—"H-....>-w — I00%laine Jfidff hautecouture |250' 1989, de 19 h 30 à 21 h 30. — Mer A, mardi 28 novembr CHOIX IMPORTANT DE LINGERIE DE TRÈS HAUTE QUALITÉ mardi 5, jeudi 7, mardi 12 décer BIJOUX FANTAISIE - CEINTURES - CHAPEAUX, etc.

. bre, de 19 h 30 à 21 h 30. VENTE LIMITÉE JUSQU'AU 18 NOVEMBRE 89 Pour tous renseignements (inscriptions s'adresser au cent OUVERTURE : Mercredi 25 oct. à 9 h. Autres jours :9h30- 19 h 30 de voile de Bordeaux-Lac, t(sons interrupïion, du lundi ou somedi inclus 56.50.95.53 (du IjUndi au vendrec de 9 heures à 12 heures et (OUVERTURE EXCEPTIONNELLE dimanche 29 oct. : 10 h-19 h 30 14 heures à 18 h 30. |^^Qf m 150' 665' Bateaux à motew HUntUI 639^ MERCREDI 2SOCTŒRE1- MER

La Correspondance économique
Les femmes, les hommes et les affaires, mardi 6 octobre 2020 3103 mots
Aussi paru dans

6 octobre 2020 | - | Bulletin Quotidien

Le Bureau du Sénat doit être constitué aujourd'hui

Le Bureau du Sénat doit être constitué aujourd'hui

Le Bureau du Sénat doit être constitué aujourd'hui

Le bureau du Sénat doit être constitué aujourd'hui.

D'importants changements devraient intervenir, avec six nouveaux vice-présidents sur huit.

Le groupe LR a désigné, pour les deux postes de vice-présidents qu'il occupe, l'ancien ministre Roger KAROUTCHI, sénateur des Hauts-de-Seine, et Mme Pascale GRUNY, sénatrice de l'Aisne.

Né en août 1951, titulaire d'une maîtrise en droit public, agrégé d'histoire, M. Roger KAROUTCHI fut délégué national du RPR à la jeunesse de (1984-1985), avant d'être chargé de mission auprès du secrétaire général du mouvement gaulliste (alors M. Jacques TOUBON) en 1985-1986. Secrétaire national du RPR à la jeunesse (1993), chargé des réformes institutionnelles (1995-1997), chargé de l'administration générale et l'animation (février-décembre 1998), puis chargé des élections (janvier-août 1999), il fut secrétaire national du RPR à la politique européenne et à l'administration générale du parti (août-décembre 1999). Chargé de mission auprès de Philippe SEGUIN au ministère des Affaires sociales et de l'Emploi (1986-1988), il fut chef de son cabinet à la présidence de l'Assemblée nationale de 1993 à février 1997, date à laquelle il fut nommé inspecteur général de l'Education nationale au tour extérieur. Conseiller régional d'Ile-de-France de 1992 à 2015, il fut vice-président de cette assemblée régionale, chargé de l'administration générale (1996-1998), et présida le groupe RPR, puis UMP au sein de ce conseil de mars 1998 à mars 2010, avant de présider la commission des Finances de cette assemblée de 2010 à 2015. Député au Parlement européen de 1997 à 1999, il présida la délégation française au sein du groupe Parti populaire européen en 1999-2000. Proclamé en décembre 1999 sénateur des Hauts-de-Seine en remplacement de Charles PASQUA, démissionnaire, il fut réélu en 2004 et fut vice-président du groupe RPR puis UMP du Sénat en 2001-2002. Secrétaire d'Etat chargé des Relations avec le Parlement dans le gouvernement de M. François FILLON, M. Roger KAROUTCHI fut ambassadeur, représentant permanent de la France auprès de l'OCDE de juillet 2009 à septembre 2011, date à laquelle il retrouva son siège de sénateur des Hauts-de-Seine. Il fut réélu en 2017, et présidait, depuis 2014, la Délégation sénatoriale à la prospective. Président de la Fédération nationale des élus régionaux de 1999 à 2007, et vice-président de l'Observatoire sénatorial de la décentralisation (2005-2007), il fut, par ailleurs, secrétaire national fonctionnel de l'UMP, chargé des fédérations et de l'animation (2005-2007), puis délégué général de l'UMP, chargé de la coordination des élus d'Ile-de-France (2007-2009).

Née en février 1960, ancienne élève de l'Ecole supérieure de commerce de Lille, Mme Pascale GRUNY fut, successivement, comptable au Centre de gestion agricole du Ham (1981-1985), au cabinet d'expertise comptable Ponthieux (1985-1990), puis au cabinet d'expertise comptable Coopers & Lybrand (1990-1995). Elle fut nommée, en 1995, directrice administrative, financière et du personnel de la société CITRA Transports. Conseillère municipale de Saint-Quentin de 2001 à 2017, 2001, elle fut proclamée en 2004, députée (app.UMP) de l'Aisne (2ème circonscription : Saint-Quentin) en remplacement de M. Xavier BERTRAND nommé secrétaire d'Etat à l'Assurance maladie et fut à nouveau proclamée députée de cette même circonscription en 2007 en remplacement de M. BERTRAND nommé ministre du Travail, des Relations sociales et de la Solidarité dans le gouvernement François FILLON, siégeant au Palais-Bourbon jusqu'en 2009. Député au Parlement européen (liste " Majorité Présidentielle - UMP - Nouveau Centre - la Gauche Moderne") inscrite au groupe PPE en 2009-2010, elle remplaça de nouveau M. Xavier BERTRAND au Palais-Bourbon de 2010 à 2012. Mme Pascale GRUNY est, depuis septembre 2014, sénatrice de l'Aisne. Conseillère départementale (élue du canton de Saint-Quentin 2) depuis 2015, elle fut vice-présidente du conseil départemental de l'Aisne de 2015 à 2017.

Le groupe socialiste, qui a perdu une vice-présidence au profit du PCF, a désigné, comme vice-présidente, l'ancienne ministre Laurence ROSSIGNOL, sénatrice de l'Oise (cf. BQ du 01/10/2020).

Née en décembre 1957, titulaire d'un diplôme d'études approfondies de droit social, Mme Laurence ROSSIGNOL fut journaliste juridique à la "Revue pratique de droit social" et parallèlement chargée de cours de droit de la Sécurité sociale à l'Université de Paris-I en 1982-1983, puis chargée d'études législatives au secrétariat du groupe socialiste à l'Assemblée nationale (1983-1988), avant d'être chargée de mission (juillet 1988-juillet 1989), chef de cabinet (juillet-octobre 1989) puis conseillère technique au cabinet de M. Laurent FABIUS à la présidence de l'Assemblée nationale (octobre 1989-juin 1991). Conseillère technique au cabinet de Mme Frédérique BREDIN au ministère de la Jeunesse et des Sports (1991-1993), elle fut ensuite chargée de mission puis directrice du service de la législation sociale de la MNEF devenue LMDE jusqu'en 2011. Elle fut par ailleurs membre du Conseil économique et social, de 1999 à 2004. Conseillère régionale (PS) de Picardie depuis 1998, et vice-présidente (PS) de ce Conseil régional, chargée de la Jeunesse, de la Vie associative et de l'Economie sociale et solidaire de 2004 à 2014, elle fut élue sénatrice de l'Oise en 2011, et réélue en 2017, et fut vice-présidente de la commission du développement durable, des infrastructures, de l'équipement et de l'aménagement du territoire du Sénat (2012-2014). Elle fut conseillère municipale de Compiègne de 2001 à 2011. Membre du conseil national du PS depuis septembre 1993, et membre du bureau national de ce parti (1997-2000), elle fut déléguée nationale du PS, chargée de la ville (1990-1993), responsable nationale pour la ville (1993-1994), déléguée nationale chargée des problèmes de la jeunesse (1994-1995), secrétaire nationale, chargée de la ville et des transports (2001-2003), responsable nationale, chargée de l'économie et de l'emploi (2003-2004), secrétaire nationale, chargée des femmes (2005-2008), puis chargée de l'environnement (2008-2012), secrétaire nationale du PS, chargée de l'écologie et du développement durable (2012-2014) et porte-parole du Parti socialiste (2013-2014), présidente du conseil national des femmes du Parti socialiste. Elle fut porte-parole de la campagne interne de Mme Martine AUBRY en vue du congrès du PS à Reims (octobre 2008), ainsi que responsable thématique "Ecologie-Energie" dans l'équipe de campagne de Mme AUBRY, candidate à la primaire socialiste pour l'élection présidentielle 2012. Secrétaire d'Etat chargée de la Famille, des Personnes âgées et de l'Autonomie dans le gouvernement de M. Manuel VALLS, (2014-2016), Mme Laurence ROSSIGNOL fut ministre des Familles, de l'Enfance et des Droits des Femmes de février 2016 à mai 2017, dans les gouvernements de MM. Manuel VALLS, puis Bernard CAZENEUVE.

Le groupe UC a confirmé ses deux vice-présidents sortants : l'ancienne ministre Valérie LETARD, sénatrice du Nord, et M. Vincent DELAHAYE, sénateur de l'Essonne.

Née en octobre 1962, titulaire d'un diplôme d'études supérieures spécialisées de développement local, Mme Valérie LETARD fut assistante sociale puis chef de projet chargée du programme de développement social des quartiers de Saint-Amand à la mairie de Saint-Amand-les-Eaux (1986-1992), avant d'être directrice du contrat de ville sur les sites intercommunaux de Valenciennes-Marly et Valenciennes-Anzin de 1992 à 1998. Conseillère régionale (UDF) du Nord-Pas-de-Calais de 1998 à 2001, de 2004 à 2010, conseillère régionale des Hauts-de-France depuis 2015, elle fut première vice-présidente de cette assemblée en 2016-2017. Elle fut adjointe au maire de Valenciennes, chargée de la politique de la ville et déléguée à la communauté d'agglomération de Valenciennes (2001-2004), avant d'être conseillère municipale et première adjointe au maire de Valenciennes (2008-2014) et présidente de Valenciennes Métropole de 2008 à 2016. Sénatrice (UC) du Nord depuis 2001, elle est vice-présidente de la Haute-Assemblée depuis 2017. Mme Valérie LETARD fut secrétaire d'Etat chargée de la Solidarité auprès du ministre du Travail, des Relations sociales et de la Solidarité de juin 2007 à juin 2009, puis secrétaire d'Etat auprès du ministre d'Etat, ministre de l'Ecologie et du Développement durable, de juin 2009 à novembre 2010 dans les gouvernements de M. François FILLON. Présidente déléguée du Nouveau Centre de 2008 à juillet 2010, puis vice-présidente de ce parti. En 2010-2011, elle est vice-présidente de l'UDI depuis 2013. Elle est la fille de M. Francis DECOURRIERE, président du Cercle démocrate, républicain et social, président du Valenciennes Football Club, ancien député au Parlement européen, ancien membre du bureau national du PSD.

Né en août 1959, expert-comptable, M. Vincent DELAHAYE fut conseiller général (UDF-PR) de l'Essonne (élu du canton de Massy-Ouest) de 1992 à 1998. Maire (Rad) de Massy de 1995 à 2017, président de la communauté d'agglomérations Europ-Essonne (2007-2015), M. Vincent DELAHAYE est sénateur (UC) de l'Essonne depuis 2011. Il est vice-président du Sénat depuis 2017.

Le groupe RDPI aura un poste de vice-président. Ce poste devrait être confié successivement à M. Georges PATIENT, né en avril 1949, sénateur (PS, puis REM) de la Guyane depuis 2008, ancien conseiller général, ancien maire de Mana, puis à l'ancien ministre Alain RICHARD, né en août 1945, ancien élève de l'ENA (promotion "Thomas More"), conseiller d'Etat honoraire, sénateur (PS, puis REM) du Val-d'Oise depuis 2011 après l'avoir été de 1995 à 1997, ancien député (PS) du Val-d'Oise, ancien maire Saint-Ouen l'Aumône, qui fut ministre de la Défense dans le gouvernement de M. Lionel JOSPIN.

Le groupe CRCE devrait désigner, comme vice-président, M. Pierre LAURENT, né en juillet 1957, sénateur (CRCE) de Paris (depuis 2012), vice-président de la commission des affaires étrangères, de la défense et des forces armées du Sénat (depuis 2018), ancien secrétaire national du Parti communiste français (PCF) (2010-2018).

Le groupe RDSE doit désigner aujourd'hui son vice-président. Ce poste pourrait être confiée à Mme Nathalie DELATTRE, née en décembre 1968, sénatrice de la Gironde depuis 2017, secrétaire générale du Mouvement Radical Social-Libéral.

Les anciens ministres Philippe BAS, sénateur (LR) de la Manche, président de la commission des Lois, et Jean-Pierre SUEUR, sénateur (PS) du Loiret, ancien président de la commission des Lois, désignés pour les fonctions de questeur

Les anciens ministres Philippe BAS, sénateur (LR) de la Manche, président de la commission des Lois, et Jean-Pierre SUEUR, sénateur (PS) du Loiret, ancien président de la commission des Lois, ont été désignés, par leurs groupes respectifs, pour occuper les fonctions de questeur.

Né en juillet 1958, diplômé de l'Institut d'études politiques de Paris, M. Philippe BAS fut nommé auditeur au Conseil d'Etat en 1984, à sa sortie de l'ENA (promotion "Louise Michel"). Il fut promu maître des requêtes en septembre 1987, et conseiller d'Etat en septembre 1999. Conseiller technique au cabinet de M. Jean-Pierre SOISSON au ministère du Travail, de l'Emploi et de la Formation professionnelle (1988-1989), il fut ensuite détaché comme conseiller juridique du président de la République du Sénégal, entre septembre 1989 et septembre 1992, avant de revenir au Conseil d'Etat. Conseiller auprès de Mme Simone VEIL, alors ministre d'Etat, ministre des Affaires sociales, de la Santé et de la Ville (1993-1994), il fut ensuite directeur adjoint de son cabinet (1994-1995), étant parallèlement conseiller auprès de M. Philippe DOUSTE-BLAZY au ministère délégué à la Santé (1993-1994). Il fut directeur du cabinet de Jacques BARROT au ministère du Travail, du Dialogue social et de la Participation (mai-novembre 1995), puis au ministère du Travail et des Affaires sociales (novembre 1995-juin 1997). Conseiller social à la présidence de la République d'octobre 1997 à septembre 2000, il en fut secrétaire général adjoint, (2000-2002), puis secrétaire général, de mai 2002 à juin 2005, aux côtés de Jacques CHIRAC. Ministre délégué à la Sécurité sociale, aux Personnes âgées, aux Personnes handicapées et à la Famille, de juin 2005 à mars 2007, puis ministre de la Santé et des Solidarités (mars-mai 2007) dans le gouvernement de M. Dominique de VILLEPIN, il réintégra le Conseil d'Etat en novembre 2007 et se vit confier, en novembre 2007, la présidence du conseil d'administration de l'Agence nationale de l'accueil des étrangers et des migrations-ANAEM devenue (mars 2009) Office français de l'immigration et de l'intégration occupant ces fonctions jusqu'en 2011. Il présida également le conseil d'administration de l'Agence nationale de sécurité sanitaire de l'alimentation, de l'environnement et du travail-ANSES (janvier-septembre 2011). Conseiller départemental (UMP, puis LR) de la Manche, depuis 2008 (élu du canton de Saint-Pois, puis du canton de Villedieu-les-Poëlles), vice-président de cette assemblée départementale de 2008 à 2015, il en fut président de 2015 2017. M. Philippe BAS fut élu sénateur de la Manche en 2011, et réélu en 2017. Il fut élu président de la commission des Lois en octobre 2014 et réélu en 2017. Président de la Délégation parlementaire au renseignement 2017-2018), il est le premier vice-président depuis juin 2020.

Né en février 1947, ancien élève de l'Ecole normale supérieure de Saint-Cloud, agrégé de lettres modernes, titulaire d'un doctorat de 3ème cycle en linguistique, M. Jean-Pierre SUEUR est maître de conférences des universités. Secrétaire national de la Jeunesse étudiante chrétienne-JEC (1967-1969), il adhéra parallèlement au PSU en 1967, avant de rejoindre le PS, en 1974. Elu député du Loiret en 1981, il fut réélu en 1986 et 1988 mais ne retrouva pas son siège en 1993. Il fut maire d'Orléans de 1989 à 2001, président de l'Association des maires des grandes villes de France (1998-2001), ainsi que conseiller régional du Centre de 1981 à 1986. Proche de Michel ROCARD, dont il fut le porte-parole en 1986-1987, il fut secrétaire d'Etat aux Collectivités locales de 1991 à 1993. Il est sénateur (PS) du Loiret depuis 2001. Vice-président de la commission des Lois de 2008 à 2011, M. Jean-Pierre SUEUR présida cette commission de 2011 à 2014. Il en était de nouveau vice-président depuis 2014.

Le groupe UC a reconduit comme questeur M. Vincent CAPO-CANELLAS, sénateur de la Seine-Saint-Denis, qui occupe ces fonctions depuis 2017.

Né en mai 1967, diplômé de l'Institut d'études politiques de Grenoble, M. Vincent CAPO-CANELLAS fut directeur de cabinet de René CRET, maire (FD) de Bagnols-sur-Cèze (1990-1995). Directeur du cabinet de Frédéric GAILLAND, maire (FD) du Bourget d'août 1995 à août 1996, il fut conseiller aux affaires régionales et politiques (août-décembre 1996) puis chef du cabinet de M. Philippe DOUSTE-BLAZY au ministère de la Culture de décembre 1996 à juin 1997. Il fut délégué national aux mouvements associés de l'UDF de novembre 1998 à janvier 2001. Premier maire adjoint (UDF) en mars à décembre 2001, puis maire (UDF, NC, puis UDI) du Bourget de 2001 à 2017, il fut président de la communauté d'agglomérations de l'Aéroport du Bourget de 2006 à 2014, et conseiller général de Seine-Saint-Denis (élu du canton du Bourget) de 2003 à 2011. M. Vincent CAPO-CANELLAS est sénateur (UC) de Seine-Saint-Denis depuis 2011, et questeur de la Haute Assemblée depuis 2017.

Cinq commissions devraient changer de président

Les présidents des commissions permanentes seront élus demain.

D'importants changements devraient intervenir.

En effet, deux présidents de commissions seulement devraient être reconduits : Mme Sophie PRIMAS, sénatrice (LR) des Yvelines, et M. Christian CAMBON, sénateur (LR) du Val-de-Marne, qui président respectivement la commission des Affaires économiques et la commission des Affaires étrangères et de la Défense depuis 2017.

Le groupe UC, renforcé à la suite du renouvellement sénatorial, devrait conserver les deux présidences de commissions qu'il exerce : la commission de l'Aménagement du territoire, et du Développement durable, présidée depuis 2014 par M. Hervé MAUREY, sénateur de l'Eure, et la commission de la Culture, de l'Education et de la Communication, présidée depuis 2014 par Mme Catherine MORIN-DESAILLY, sénatrice de Seine-Maritime, qui ne seront pas renouvelés.

La présidence de la commission des Lois devrait être confiée à M. François-Noël BUFFET, né en août 1963, sénateur (LR) du Rhône depuis 2004, vice-président de la commission des lois constitutionnelles, de la législation, du suffrage universel, du règlement et d'administration générale (depuis 2015), en remplacement de M. Philippe BAS.

La présidence de la commission de l'Aménagement du territoire, et du Développement durable devrait être confiée à M. Jean-François LONGEOT, né en décembre 1956, sénateur du Doubs depuis 2014, ancien conseiller général et ancien maire d'Ormans.

M. Laurent LAFON, né en décembre 1965, sénateur (UC) du Val-de-Marne depuis 2017, ancien maire (UDI) de Vincennes, ancien conseiller régional d'Ile-de-France, a été désigné par le groupe UC pour succéder à Mme Catherine MORIN-DESAILLY à la présidence de la commission de la Culture, de l'Education et de la Communication.

La présidence de la commission des Finances sera confiée à un élu socialiste, en remplacement de M. Vincent EBLE, sénateur de Seine-et-Marne. C'est M. Claude RAYNAL, né en octobre 1957, ancien élève de l'ENA, (promotion "Cyrano de Bergerac"), premier conseiller de tribunal administratif et de Cour administrative d'appel, sénateur (PS) de la Haute-Garonne depuis 2014, ancien conseiller général, andin maire de Tournefeuille, qui a été désigné par le groupe socialiste (cf. BQ du 265/09/2020). Les fonctions de rapporteur général de la commission devraient être confiées à M. Jean-François HUSSON, né en avril 1961, sénateur (LR) de la Meurthe-et-Moselle (depuis 2011), vice-président de la commission des Finances (depuis 2017).

Mme Catherine DEROCHE, née en février 1953, médecin, cancérologue, sénatrice (LR) du Maine-et-Loire depuis 2010, conseillère régionale des Pays-de-la-Loire, ancienne maire de Bouchemaine, devrait présider la commission des Affaires sociales en remplacement de M. Alain MILON, sénateur du Vaucluse, qui assurait cette présidence depuis 2015.

La présidence de la commission des Affaires européennes serait quant à elle confiée à M. Jean-François RAPIN, né en mai 1956, sénateur (LR) du Pas-de-Calais (depuis 2016), conseiller régional (LR) des Hauts-de-France depuis 2015.

Par ailleurs, Mme Elisabeth DOINEAU, née en avril 1961, sénatrice (UC) de la Mayenne depuis 2001 (élue du canton de Saint-Aignan-sur-Roë, puis du canton de Cossé-le-Vivien, ancienne maire de La Rouaudière, ancienne conseillère régionale des Pays-de-la-Loire, devrait se voir confier, au cours du premier trimestre de l'année 2021, les fonctions de rapporteure générale de la commission des affaires sociales, en remplacement de M. Jean-Marie VANLERENBERGHE, sénateur du Pas-de-Calais depuis 2001, qui exerce ces fonctions depuis 2014. Le changement n'interviendrait bien évidemment qu'après l'adoption définitive du projet de loi de financements de la sécurité sociale pour 2021.

Changements pour les présidences de délégations

Trois présidents de délégations ne se représentent pas (cf. infra) : l'ancien ministre Jean-Marie BOCKEL, président de la délégation aux Collectivités territoriales, Mme Elisabeth LAMURE, sénatrice du Rhône, présidente de la délégation aux Entreprises, et M. Michel MARGRAS, sénateur de Saint-Barthélemy, président de la délation à l'Outre-mer (cf. BQ du 25/09/2020).

Pour remplacer M. Jean-Marie BOCKEL à la présidence de la Délégation aux Collectivités territoriales, le groupe UC a désigné Mme Françoise GATEL, née en mars 1953, sénatrice d'Ille-et-Vilaine depuis 2014, ancienne maire de Chateaugiron.

En outre Mme Annick BILLON, née en aout 1967, sénatrice (UC) de la Vendée depuis 2014, devrait conserver la présidence de la délégation aux Droits des femmes et à l'égalité des chances entre les hommes et les femmes.

M. Pierre FROGIER, né en novembre 1950, sénateur (LR) de Nouvelle-Calédonie depuis 2011, ancien député, ancien maire de Mont-Dore, devrait se voir confier la présidence de la Délégation à l'Outre-mer.

M. Serge BABARY, né en juillet 1646, sénateur (LR) de l'Indre-et-Loire (depuis 2017), se verrait confier la présidence de la délégation aux entreprises en remplacement de Mme Elisabeth LAMURE.